@@ -2,10 +2,11 @@
 /*!	\file about.cpp
 **	\brief writeme
 **
-**	$Id: about.cpp 488 2007-05-27 23:43:55Z pabs $
+**	$Id: about.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -158,25 +159,25 @@ public:
 /* === M E T H O D S ======================================================= */
 
 About::About():
-	Gtk::Window(Gtk::WINDOW_POPUP),
+	Gtk::Window(getenv("SYNFIG_DISABLE_POPUP_WINDOWS") ? Gtk::WINDOW_TOPLEVEL : Gtk::WINDOW_POPUP),
 	can_self_destruct(true)
 {
 	int image_w=300,image_h=350;
 
 	std::string imagepath;
 #ifdef WIN32
-	imagepath=App::get_base_path()+ETL_DIRECTORY_SEPERATOR+IMAGE_DIR;
+	imagepath=App::get_base_path()+ETL_DIRECTORY_SEPARATOR+IMAGE_DIR;
 #else
 	imagepath=IMAGE_DIR;
 #endif
 	char* synfig_root=getenv("SYNFIG_ROOT");
 	if(synfig_root) {
 		imagepath=synfig_root;
-		imagepath+=ETL_DIRECTORY_SEPERATOR;
+		imagepath+=ETL_DIRECTORY_SEPARATOR;
 
 		imagepath+="share/pixmaps";
 	}
-	imagepath+=ETL_DIRECTORY_SEPERATOR;
+	imagepath+=ETL_DIRECTORY_SEPARATOR;
 
 
 	// Create the Logo
@@ -203,7 +204,7 @@ About::About():
 	Pango::FontDescription fd = Pango::FontDescription("Sans, 11");
 	l->set_font_description(fd);
 	l->set_justify(Pango::ALIGN_CENTER);
-	fd.set_size(size*Pango::SCALE);
+	fd.set_size(int(size*Pango::SCALE));
 	l->set_font_description(fd);
 	l->get_pixel_size(width,height);
 	while( width >= image_w-6 ){
@@ -248,7 +249,7 @@ About::About():
 	fd = Pango::FontDescription("Sans, 11");
 	l->set_font_description(fd);
 	l->set_justify(Pango::ALIGN_CENTER);
-	fd.set_size(size*Pango::SCALE);
+	fd.set_size(int(size*Pango::SCALE));
 	l->set_font_description(fd);
 	l->get_pixel_size(width,height);
 	while( width >= image_w-6 ){
