@@ -2,10 +2,11 @@
 /*!	\file app.h
 **	\brief writeme
 **
-**	$Id: app.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: app.h 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -262,6 +263,7 @@ public:
 	static synfig::String get_base_path();
 	static void save_settings();
 	static void load_settings();
+	static void reset_initial_window_configuration();
 
 	static const std::list<std::string>& get_recent_files();
 
@@ -306,7 +308,6 @@ public:
 
 	static bool dialog_open_file(const std::string &title, std::string &filename);
 	static bool dialog_save_file(const std::string &title, std::string &filename);
-	static bool dialog_saveas_file(const std::string &title, std::string &filename);
 
 	static void dialog_error_blocking(const std::string &title, const std::string &message);
 
