@@ -2,10 +2,11 @@
 /*!	\file cellrenderer_timetrack.cpp
 **	\brief Template Header
 **
-**	$Id: cellrenderer_timetrack.cpp 388 2007-03-27 15:12:12Z dooglus $
+**	$Id: cellrenderer_timetrack.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -199,10 +200,10 @@ void
 CellRenderer_TimeTrack::render_vfunc(
 		const Glib::RefPtr<Gdk::Drawable>& window,
 		Gtk::Widget& widget,
-		const Gdk::Rectangle& background_area,
+		const Gdk::Rectangle& /*background_area*/,
 		const Gdk::Rectangle& area_,
-		const Gdk::Rectangle& expose_area,
-		Gtk::CellRendererState flags)
+		const Gdk::Rectangle& /*expose_area*/,
+		Gtk::CellRendererState /*flags*/)
 {
 	if(!window)
 		return;
@@ -529,7 +530,7 @@ CellRenderer_TimeTrack::render_vfunc(
 }
 
 synfig::ValueNode_Animated::WaypointList::iterator
-CellRenderer_TimeTrack::find_waypoint(const synfig::Time& t,const synfig::Time& scope)
+CellRenderer_TimeTrack::find_waypoint(const synfig::Time& /*t*/,const synfig::Time& scope)
 {
 	synfig::ValueNode_Animated *value_node=dynamic_cast<synfig::ValueNode_Animated*>(property_value_desc().get_value().get_value_node().get());
 
@@ -564,11 +565,11 @@ CellRenderer_TimeTrack::find_waypoint(const synfig::Time& t,const synfig::Time&
 bool
 CellRenderer_TimeTrack::activate_vfunc(
 	GdkEvent* event,
-	Gtk::Widget& widget,
+	Gtk::Widget& /*widget*/,
 	const Glib::ustring& treepath,
-	const Gdk::Rectangle& background_area,
+	const Gdk::Rectangle& /*background_area*/,
 	const Gdk::Rectangle& cell_area,
-	Gtk::CellRendererState flags)
+	Gtk::CellRendererState /*flags*/)
 {
 	path=treepath;
 	synfig::ValueNode_Animated::WaypointList::iterator iter;
@@ -920,6 +921,15 @@ CellRenderer_TimeTrack::show_timepoint_menu(const etl::handle<synfig::Node>& nod
 		Gtk::Menu* interp_menu(manage(new Gtk::Menu()));
 		Waypoint::Model model;
 
+		// note: each of the following 4 'if' blocks provokes these warnings:
+		//  /usr/include/sigc++-2.0/sigc++/adaptors/bound_argument.h:57: warning:
+		//  'model.synfig::Waypoint::Model::temporal_tension' is used uninitialized in this function
+		//	'model.synfig::Waypoint::Model::bias' is used uninitialized in this function
+		//	'model.synfig::Waypoint::Model::continuity' is used uninitialized in this function
+		//	'model.synfig::Waypoint::Model::tension' is used uninitialized in this function
+		//	'model.synfig::Waypoint::Model::priority' is used uninitialized in this function
+		// I don't know if that matters or not.
+
 		if(side==SIDE_LEFT)model.set_before(INTERPOLATION_TCB);
 		else model.set_after(INTERPOLATION_TCB);
 		interp_menu->items().push_back(Gtk::Menu_Helpers::MenuElem(_("TCB"),
