@@ -2,7 +2,7 @@
 /*!	\file cellrenderer_value.cpp
 **	\brief Template File
 **
-**	$Id: cellrenderer_value.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: cellrenderer_value.cpp 750 2007-09-25 08:33:54Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -65,11 +65,6 @@ using namespace studio;
 
 #define DIGITS		15
 
-#define use_colorspace_gamma()	App::use_colorspace_gamma
-#define colorspace_gamma()	(2.2f)
-#define gamma_in(x)		pow((float)x,1.0f/colorspace_gamma())
-#define gamma_out(x)	pow((float)x,colorspace_gamma())
-
 /* === G L O B A L S ======================================================= */
 
 class studio::ValueBase_Entry : public Gtk::EventBox, public Gtk::CellEditable
@@ -154,7 +149,7 @@ public:
 		if(parent)parent->grab_focus();
 		Gtk::CellEditable::on_remove_widget();
 	}
-	void start_editing_vfunc(GdkEvent *event)
+	void start_editing_vfunc(GdkEvent */*event*/)
 	{
 		valuewidget->signal_activate().connect(sigc::mem_fun(*this, &studio::ValueBase_Entry::editing_done));
 		show();
