@@ -2,10 +2,11 @@
 /*!	\file childrentreestore.cpp
 **	\brief Template File
 **
-**	$Id: childrentreestore.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: childrentreestore.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -169,7 +170,7 @@ ChildrenTreeStore::refresh_canvases()
 }
 
 void
-ChildrenTreeStore::refresh_row(Gtk::TreeModel::Row &row, bool do_children)
+ChildrenTreeStore::refresh_row(Gtk::TreeModel::Row &row, bool /*do_children*/)
 {
 	CanvasTreeStore::refresh_row(row,false);
 
@@ -204,7 +205,7 @@ ChildrenTreeStore::on_canvas_added(Canvas::Handle canvas)
 }
 
 void
-ChildrenTreeStore::on_canvas_removed(Canvas::Handle canvas)
+ChildrenTreeStore::on_canvas_removed(Canvas::Handle /*canvas*/)
 {
 	rebuild_canvases();
 }
@@ -297,7 +298,7 @@ void
 ChildrenTreeStore::on_value_node_changed(etl::handle<ValueNode> value_node)
 {
 
-	if(value_node->get_name()=="constant" || !value_node->is_exported())
+	if(!value_node->is_exported())
 		return;
 	changed_connection.disconnect();
 //	if(!execute_changed_queued())
@@ -329,7 +330,7 @@ ChildrenTreeStore::on_value_node_changed(etl::handle<ValueNode> value_node)
 }
 
 void
-ChildrenTreeStore::on_value_node_replaced(synfig::ValueNode::Handle replaced_value_node,synfig::ValueNode::Handle new_value_node)
+ChildrenTreeStore::on_value_node_replaced(synfig::ValueNode::Handle replaced_value_node,synfig::ValueNode::Handle /*new_value_node*/)
 {
 	changed_connection.disconnect();
 	//if(!execute_changed_queued())
