@@ -2,7 +2,7 @@
 /*!	\file dialog_gradient.cpp
 **	\brief Template File
 **
-**	$Id: dialog_gradient.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: dialog_gradient.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -171,7 +171,7 @@ Dialog_Gradient::on_values_adjusted()
 }
 
 static void
-dialog_gradient_value_desc_edit(synfig::Gradient g,synfigapp::ValueDesc x,handle<synfigapp::CanvasInterface> canvas_interface)
+dialog_gradient_value_desc_edit(synfig::Gradient /*g*/,synfigapp::ValueDesc /*x*/,handle<synfigapp::CanvasInterface> /*canvas_interface*/)
 {
 //	canvas_interface->connect_value(x,ValueBase(g));
 }
