@@ -2,7 +2,7 @@
 /*!	\file dialog_keyframe.h
 **	\brief Template Header
 **
-**	$Id: dialog_keyframe.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: dialog_keyframe.h 725 2007-09-21 00:26:34Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -70,7 +70,7 @@ public:
 
 private:
 
-}; // END of class RenderSettings
+}; // END of class Dialog_Keyframe
 
 }; // END of namespace studio
 
