@@ -2,7 +2,7 @@
 /*!	\file dialog_soundselect.cpp
 **	\brief Template File
 **
-**	$Id: dialog_soundselect.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: dialog_soundselect.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -50,7 +50,7 @@ using namespace synfig;
 
 /* === E N T R Y P O I N T ================================================= */
 
-studio::Dialog_SoundSelect::Dialog_SoundSelect(Gtk::Window &parent, etl::handle<synfigapp::CanvasInterface> ci)
+studio::Dialog_SoundSelect::Dialog_SoundSelect(Gtk::Window &/*parent*/, etl::handle<synfigapp::CanvasInterface> ci)
 :Dialog(_("Sound Select")),
 okbutton(_("Ok")),
 canvas_interface(ci)
