@@ -2,7 +2,7 @@
 /*!	\file dock_canvasspecific.cpp
 **	\brief Template File
 **
-**	$Id: dock_canvasspecific.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: dock_canvasspecific.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -85,17 +85,17 @@ Dock_CanvasSpecific::get_canvas_interface()
 }
 
 void
-Dock_CanvasSpecific::init_canvas_view_vfunc(etl::loose_handle<CanvasView> canvas_view)
+Dock_CanvasSpecific::init_canvas_view_vfunc(etl::loose_handle<CanvasView> /*canvas_view*/)
 {
 }
 
 void
-Dock_CanvasSpecific::init_instance_vfunc(etl::loose_handle<Instance> instance)
+Dock_CanvasSpecific::init_instance_vfunc(etl::loose_handle<Instance> /*instance*/)
 {
 }
 
 void
-Dock_CanvasSpecific::changed_canvas_view_vfunc(etl::loose_handle<CanvasView> canvas_view)
+Dock_CanvasSpecific::changed_canvas_view_vfunc(etl::loose_handle<CanvasView> /*canvas_view*/)
 {
 }
 
@@ -109,7 +109,7 @@ Dock_CanvasSpecific::init_instance(etl::handle<Instance> instance)
 }
 
 void
-Dock_CanvasSpecific::delete_instance(etl::handle<Instance> instance)
+Dock_CanvasSpecific::delete_instance(etl::handle<Instance> /*instance*/)
 {
 	changed_canvas_view_vfunc(0);
 }
