@@ -2,10 +2,11 @@
 /*!	\file dock_info.cpp
 **	\brief Dock Info File
 **
-**	$Id: dock_info.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: dock_info.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -34,6 +35,7 @@
 #include "workarea.h"
 
 #include <synfig/canvas.h>
+#include <synfig/color.h>		// for gamma_in()
 #include <synfig/context.h>
 
 #include <gtkmm/separator.h>
@@ -48,10 +50,6 @@ using namespace etl;
 using namespace synfig;
 
 /* === M A C R O S ========================================================= */
-#define use_colorspace_gamma()	App::use_colorspace_gamma
-#define colorspace_gamma()	(2.2f)
-#define gamma_in(x)		((x>=0)?pow((float)x,1.0f/colorspace_gamma()):-pow((float)-x,1.0f/colorspace_gamma()))
-#define gamma_out(x)	((x>=0)?pow((float)x,colorspace_gamma()):-pow((float)-x,colorspace_gamma()))
 
 /* === G L O B A L S ======================================================= */
 
@@ -107,7 +105,7 @@ studio::Dock_Info::Dock_Info()
 	table->attach(x,1,2,0,2,Gtk::EXPAND|Gtk::FILL,Gtk::SHRINK|Gtk::FILL);
 	table->attach(y,1,2,2,4,Gtk::EXPAND|Gtk::FILL,Gtk::SHRINK|Gtk::FILL);
 
-	//seperator
+	//separator
 	table->attach(*manage(new Gtk::VSeparator),2,3,0,4,Gtk::EXPAND|Gtk::FILL,Gtk::SHRINK|Gtk::FILL);
 
 	//color label
