@@ -2,10 +2,11 @@
 /*!	\file dock_layers.cpp
 **	\brief Template File
 **
-**	$Id: dock_layers.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: dock_layers.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -111,7 +112,7 @@ Dock_Layers::Dock_Layers():
 		Glib::RefPtr<Gtk::ActionGroup> action_group_categories(Gtk::ActionGroup::create("layer-category"));
 		synfig::String layer_ui_info;
 
-		layer_ui_info+="<ui><menubar action='menu-main'><menu action='menu-layer'><menu action='menu-layer-new'>";
+		layer_ui_info+="<ui><popup action='menu-main'><menu action='menu-layer'><menu action='menu-layer-new'>";
 
 		std::map<synfig::String,synfig::String>::iterator iter;
 		for(iter=category_map.begin();iter!=category_map.end();++iter)
@@ -120,7 +121,7 @@ Dock_Layers::Dock_Layers():
 			action_group_categories->add(Gtk::Action::create(iter->first.c_str(),iter->first.c_str()));
 		}
 
-		layer_ui_info+="</menu></menu></menubar></ui>";
+		layer_ui_info+="</menu></menu></popup></ui>";
 
 		App::ui_manager()->insert_action_group(action_group_categories);
 		App::ui_manager()->insert_action_group(action_group_new_layers);
