@@ -2,10 +2,11 @@
 /*!	\file dock_navigator.cpp
 **	\brief Dock Nagivator File
 **
-**	$Id: dock_navigator.cpp 525 2007-06-13 16:41:26Z dooglus $
+**	$Id: dock_navigator.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -255,7 +256,7 @@ static double zoom_to_unit(double f)
 	}else return -999999.0;
 }
 
-bool studio::Widget_NavView::on_expose_draw(GdkEventExpose *exp)
+bool studio::Widget_NavView::on_expose_draw(GdkEventExpose */*exp*/)
 {
 	//print out the zoom
 	//HACK kind of...
