@@ -2,10 +2,11 @@
 /*!	\file dock_timetrack.cpp
 **	\brief Template File
 **
-**	$Id: dock_timetrack.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: dock_timetrack.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -349,12 +350,18 @@ public:
 			if(adjustment.get_page_size()>get_height())
 				adjustment.set_page_size(get_height());
 
-			cellrenderer_time_track->set_fixed_size(-1,18);
+			int row_height = 0;
+			if(getenv("SYNFIG_TIMETRACK_ROW_HEIGHT"))
+				row_height = atoi(getenv("SYNFIG_TIMETRACK_ROW_HEIGHT"));
+			if (row_height < 3)
+				row_height = 18;
+									  
+			cellrenderer_time_track->set_fixed_size(-1,row_height);
 		}
 	}
 
 	void
-	on_waypoint_clicked(const Glib::ustring &path_string, synfig::Waypoint waypoint,int button)
+	on_waypoint_clicked(const Glib::ustring &/*path_string*/, synfig::Waypoint waypoint,int button)
 	{
 /*
 		Gtk::TreePath path(path_string);
@@ -394,7 +401,14 @@ Dock_Timetrack::Dock_Timetrack():
 {
 	table_=0;
 	widget_timeslider_= new Widget_Timeslider();
-	widget_timeslider_->set_size_request(-1,22);
+
+	int header_height = 0;
+	if(getenv("SYNFIG_TIMETRACK_HEADER_HEIGHT"))
+		header_height = atoi(getenv("SYNFIG_TIMETRACK_HEADER_HEIGHT"));
+	if (header_height < 3)
+		header_height = 22;
+
+	widget_timeslider_->set_size_request(-1,header_height);
 	hscrollbar_=new Gtk::HScrollbar();
 	vscrollbar_=new Gtk::VScrollbar();
 }
