@@ -2,7 +2,7 @@
 /*!	\file dockable.cpp
 **	\brief Template File
 **
-**	$Id: dockable.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: dockable.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -201,7 +201,7 @@ Dockable::on_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context, i
 }
 
 void
-Dockable::on_drag_end(const Glib::RefPtr<Gdk::DragContext>&context)
+Dockable::on_drag_end(const Glib::RefPtr<Gdk::DragContext>&/*context*/)
 {
 	if(!dnd_success_)
 	{
@@ -211,13 +211,13 @@ Dockable::on_drag_end(const Glib::RefPtr<Gdk::DragContext>&context)
 }
 
 void
-Dockable::on_drag_begin(const Glib::RefPtr<Gdk::DragContext>&context)
+Dockable::on_drag_begin(const Glib::RefPtr<Gdk::DragContext>&/*context*/)
 {
 	dnd_success_=false;
 }
 
 void
-Dockable::on_drag_data_get(const Glib::RefPtr<Gdk::DragContext>&, Gtk::SelectionData& selection_data, guint info, guint time)
+Dockable::on_drag_data_get(const Glib::RefPtr<Gdk::DragContext>&, Gtk::SelectionData& selection_data, guint /*info*/, guint /*time*/)
 {
 	Dockable* tmp(this);
 	dnd_success_=true;
