@@ -2,10 +2,11 @@
 /*!	\file dockdialog.cpp
 **	\brief Template File
 **
-**	$Id: dockdialog.cpp 454 2007-04-11 14:35:44Z dooglus $
+**	$Id: dockdialog.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -144,14 +145,12 @@ DockDialog::~DockDialog()
 
 	is_deleting=true;
 
-	DEBUGPOINT();
-
 	// Remove all of the dock books
 	for(;!dock_book_list.empty();dock_book_list.pop_front())
 	{
 		dock_book_list.front()->clear();
 
-		// UGLY HACK
+		//! \fixme: UGLY HACK
 		// The following line really should be uncommented,
 		// but it causes crashes. Without it, a small
 		// memory hole is created--but at least it doesn't crash
@@ -160,8 +159,14 @@ DockDialog::~DockDialog()
 		// Oddly enough, the following line should
 		// theoreticly do the same thing after this
 		// class is destroyed, but it doesn't seem to
-		// caues a crash.
-		manage(dock_book_list.front());
+		// cause a crash.  It does, however, trigger this warning:
+		//
+		//   A floating object was finalized. This means that someone
+		//   called g_object_unref() on an object that had only a
+		//   floating reference; the initial floating reference is not
+		//   owned by anyone and must be removed with g_object_ref_sink().
+		//
+		// manage(dock_book_list.front());
 	}
 
 	// Remove us from the dock manager
@@ -180,8 +185,6 @@ DockDialog::~DockDialog()
 	}
 
 	delete widget_comp_select;
-
-	DEBUGPOINT();
 }
 
 void
@@ -299,7 +302,7 @@ DockDialog::erase_dock_book(DockBook* dock_book)
 void
 DockDialog::refresh()
 {
-	synfig::info("dock_book_list.size()=%d",dock_book_list.size());
+	// synfig::info("dock_book_list.size()=%d",dock_book_list.size());
 	//remove();
 
 	if(dock_book_list.empty())
