@@ -2,10 +2,11 @@
 /*!	\file dockmanager.cpp
 **	\brief Template File
 **
-**	$Id: dockmanager.cpp 478 2007-04-18 10:19:19Z dooglus $
+**	$Id: dockmanager.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -229,7 +230,7 @@ DockManager::~DockManager()
 	while(!dockable_list_.empty())
 	{
 		Dockable* dockable(dockable_list_.back());
-		synfig::info("DockManager::~DockManager(): Deleting dockable \"%s\"",dockable->get_name().c_str());
+		// synfig::info("DockManager::~DockManager(): Deleting dockable \"%s\"",dockable->get_name().c_str());
 		dockable_list_.pop_back();
 		delete dockable;
 	}
@@ -239,7 +240,7 @@ void
 DockManager::register_dockable(Dockable& x)
 {
 	dockable_list_.push_back(&x);
-	synfig::info("DockManager::register_dockable(): Registered dockable \"%s\"",dockable_list_.back()->get_name().c_str());
+	// synfig::info("DockManager::register_dockable(): Registered dockable \"%s\"",dockable_list_.back()->get_name().c_str());
 	signal_dockable_registered()(&x);
 }
 
