@@ -2,10 +2,11 @@
 /*!	\file duckmatic.cpp
 **	\brief Template File
 **
-**	$Id: duckmatic.cpp 468 2007-04-13 12:39:43Z dooglus $
+**	$Id: duckmatic.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -256,11 +257,8 @@ Duckmatic::is_duck_group_selectable(const etl::handle<Duck>& x)const
 			layer_name=="curve_gradient"
 		)
 			return false;
-		if(
-			(layer_name=="PasteCanvas"||
-			layer_name=="paste_canvas")
-			&& !layer->get_param("children_lock").get(bool())
-		)
+		if((layer_name=="PasteCanvas"|| layer_name=="paste_canvas") &&
+		   !layer->get_param("children_lock").get(bool()))
 			return false;
 	}
 	return true;
@@ -275,6 +273,25 @@ Duckmatic::select_all_ducks()
 			select_duck(iter->second);
 }
 
+void
+Duckmatic::toggle_select_ducks_in_box(const synfig::Vector& tl,const synfig::Vector& br)
+{
+	Vector vmin, vmax;
+	vmin[0]=std::min(tl[0],br[0]);
+	vmin[1]=std::min(tl[1],br[1]);
+	vmax[0]=std::max(tl[0],br[0]);
+	vmax[1]=std::max(tl[1],br[1]);
+
+	DuckMap::const_iterator iter;
+	for(iter=duck_map.begin();iter!=duck_map.end();++iter)
+	{
+		Point p(iter->second->get_trans_point());
+		if(p[0]<=vmax[0] && p[0]>=vmin[0] && p[1]<=vmax[1] && p[1]>=vmin[1] &&
+		   is_duck_group_selectable(iter->second))
+			toggle_select_duck(iter->second);
+	}
+}
+
 void
 Duckmatic::select_ducks_in_box(const synfig::Vector& tl,const synfig::Vector& br)
 {
@@ -1436,7 +1453,7 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 								duck->set_origin(last_duck());
 /*
 								ValueBase value(synfigapp::ValueDesc(value_desc.get_layer(),param_desc->get_origin()).get_value(get_time()));
-								if(value.same_as(synfig::Point()))
+								if(value.same_type_as(synfig::Point()))
 									duck->set_origin(value.get(synfig::Point()));
 */
 							}
@@ -1465,7 +1482,7 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 								duck->set_origin(last_duck());
 /*
 								ValueBase value(synfigapp::ValueDesc(value_desc.get_layer(),param_desc->get_origin()).get_value(get_time()));
-								if(value.same_as(synfig::Point()))
+								if(value.same_type_as(synfig::Point()))
 									duck->set_origin(value.get(synfig::Point()));
 */
 						}
@@ -1487,7 +1504,7 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 						width->set_name(guid_string(synfigapp::ValueDesc(value_node,i))+".w");
 						{
 							ValueBase value(synfigapp::ValueDesc(value_desc.get_layer(),param_desc->get_hint()).get_value(get_time()));
-							if(value.same_as(synfig::Real()))
+							if(value.same_type_as(synfig::Real()))
 								width->set_scalar(value.get(synfig::Real())*0.5f);
 						}
 					}
@@ -1593,7 +1610,7 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 								duck->set_origin(last_duck());
 /*
 								ValueBase value(synfigapp::ValueDesc(value_desc.get_layer(),param_desc->get_origin()).get_value(get_time()));
-								if(value.same_as(synfig::Point()))
+								if(value.same_type_as(synfig::Point()))
 									duck->set_origin(value.get(synfig::Point()));
 */
 //						if(!param_desc->get_origin().empty())
@@ -1748,7 +1765,7 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 								duck->set_origin(last_duck());
 /*
 								ValueBase value(synfigapp::ValueDesc(value_desc.get_layer(),param_desc->get_origin()).get_value(get_time()));
-								if(value.same_as(synfig::Point()))
+								if(value.same_type_as(synfig::Point()))
 									duck->set_origin(value.get(synfig::Point()));
 */
 //						if(!param_desc->get_origin().empty())
