@@ -2,7 +2,7 @@
 /*!	\file historytreestore.cpp
 **	\brief Template File
 **
-**	$Id: historytreestore.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: historytreestore.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -103,7 +103,7 @@ HistoryTreeStore::rebuild()
 }
 
 void
-HistoryTreeStore::insert_action(Gtk::TreeRow row,etl::handle<synfigapp::Action::Undoable> action, bool is_active, bool is_undo, bool is_redo)
+HistoryTreeStore::insert_action(Gtk::TreeRow row,etl::handle<synfigapp::Action::Undoable> action, bool /*is_active*/, bool is_undo, bool is_redo)
 {
 	assert(action);
 
