@@ -2,10 +2,11 @@
 /*!	\file iconcontroler.cpp
 **	\brief Template File
 **
-**	$Id: iconcontroler.cpp 369 2007-03-23 00:28:54Z dooglus $
+**	$Id: iconcontroler.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -72,7 +73,11 @@ using namespace synfig;
 
 static Glib::RefPtr<Gdk::Pixbuf> _tree_pixbuf_table_value_type[(int)synfig::ValueBase::TYPE_END];
 
+#ifdef WIN32
 IconControler::IconControler(const synfig::String& basepath)
+#else
+IconControler::IconControler(const synfig::String& /*basepath*/)
+#endif
 {
 	Gtk::IconSource icon_source;
 	icon_source.set_direction_wildcarded();
@@ -90,11 +95,11 @@ IconControler::IconControler(const synfig::String& basepath)
 	char* synfig_root=getenv("SYNFIG_ROOT");
 	if(synfig_root) {
 		path_to_icons=synfig_root;
-		path_to_icons+=ETL_DIRECTORY_SEPERATOR;
+		path_to_icons+=ETL_DIRECTORY_SEPARATOR;
 
-		path_to_icons+="share/pixmaps";
+		path_to_icons+="share/pixmaps/synfigstudio";
 	}
-	path_to_icons+=ETL_DIRECTORY_SEPERATOR;
+	path_to_icons+=ETL_DIRECTORY_SEPARATOR;
 
 	try{
 	Gtk::Window::set_default_icon_from_file(path_to_icons+"synfig_icon."+IMAGE_EXT);
@@ -150,7 +155,7 @@ IconControler::IconControler(const synfig::String& basepath)
 	INIT_STOCK_ICON(saveall,"saveall_icon."IMAGE_EXT,_("Save All"));
 	INIT_STOCK_ICON(bool,"bool_icon."IMAGE_EXT,_("Bool"));
 	INIT_STOCK_ICON(layer,"layer_icon."IMAGE_EXT,_("Layer"));
-	INIT_STOCK_ICON(layer_pastecanvas,"pastecanvas_icon."IMAGE_EXT,_("PasteCanvas"));
+	INIT_STOCK_ICON(layer_pastecanvas,"pastecanvas_icon."IMAGE_EXT,_("Paste Canvas"));
 	INIT_STOCK_ICON(group,"group_icon."IMAGE_EXT,_("Group"));
 	INIT_STOCK_ICON(grid_enable,"grid_enable_icon."IMAGE_EXT,_("Show Grid"));
 	INIT_STOCK_ICON(grid_disable,"grid_disable_icon."IMAGE_EXT,_("Hide Grid"));
@@ -355,7 +360,7 @@ studio::get_action_stock_id(const synfigapp::Action::BookEntry& action)
 Gtk::StockID
 studio::layer_icon(const synfig::String &layer)
 {
-	if(layer=="PasteCanvas" || layer=="pastecanvas")
+	if(layer=="PasteCanvas" || layer=="pastecanvas" || layer=="paste_canvas")
 		return Gtk::StockID("synfig-layer_pastecanvas");
 	else if(layer=="rotate")
 		return Gtk::StockID("synfig-rotate");
