@@ -2,10 +2,11 @@
 /*!	\file gtkmm/instance.h
 **	\brief writeme
 **
-**	$Id: instance.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: instance.h 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -37,6 +38,7 @@
 #include <synfig/canvas.h>
 
 /* === M A C R O S ========================================================= */
+#define DEFAULT_FILENAME_PREFIX _("Synfig Animation ") // will be followed by a different number for each document
 
 /* === T Y P E D E F S ===================================================== */
 
@@ -54,6 +56,13 @@ class Instance : public synfigapp::Instance
 public:
 	typedef std::list< etl::handle<CanvasView> > CanvasViewList;
 
+	enum Status
+	{
+		STATUS_OK,
+		STATUS_ERROR,
+		STATUS_CANCEL
+	};
+
 	class CanvasTreeModel : public Gtk::TreeModel::ColumnRecord
 	{
 	public:
@@ -167,14 +176,13 @@ public:
 
 	const CanvasViewList & canvas_view_list()const { return canvas_view_list_; }
 
-	bool save_as(const synfig::String &filename)const;
-
 	bool save_as(const synfig::String &filename);
 
 	//! Opens a "Save As" dialog, and then saves the composition to that file
-	void dialog_save_as();
+	//! returns true if the save was successful
+	bool dialog_save_as();
 
-	bool save();
+	Status save();
 
 	void dialog_cvs_commit();
 
