@@ -2,10 +2,11 @@
 /*!	\file ipc.cpp
 **	\brief Template File
 **
-**	$Id: ipc.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: ipc.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -329,7 +330,7 @@ IPC::make_connection()
 		ret=SmartFILE(fdopen(fd,"w"));
 
 #ifdef _DEBUG
-	synfig::info("uplink fd=%d",fd);
+	// synfig::info("uplink fd=%d",fd);
 #endif
 
 	return ret;
