@@ -2,10 +2,11 @@
 /*!	\file keyframeactionmanager.cpp
 **	\brief Template File
 **
-**	$Id: keyframeactionmanager.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: keyframeactionmanager.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -238,7 +239,7 @@ KeyframeActionManager::refresh()
 			action->set_sensitive(false);
 	}
 
-	ui_info="<ui><menubar action='menu-main'><menu action='menu-keyframe'>"+ui_info+"</menu></menubar></ui>";
+	ui_info="<ui><popup action='menu-main'><menu action='menu-keyframe'>"+ui_info+"</menu></popup></ui>";
 	popup_id_=get_ui_manager()->add_ui_from_string(ui_info);
 #ifdef ONE_ACTION_GROUP
 #else
