@@ -2,10 +2,11 @@
 /*!	\file keyframetreestore.cpp
 **	\brief Template File
 **
-**	$Id: keyframetreestore.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: keyframetreestore.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -188,7 +189,7 @@ KeyframeTreeStore_Class::init()
 }
 
 void
-KeyframeTreeStore_Class::class_init_function(gpointer g_class, gpointer class_data)
+KeyframeTreeStore_Class::class_init_function(gpointer /*g_class*/, gpointer /*class_data*/)
 {
 	// ???
 }
@@ -258,7 +259,7 @@ KeyframeTreeStore::iterator_sane(const Gtk::TreeModel::iterator& iter)const
 }
 
 inline void
-KeyframeTreeStore::dump_iterator(const GtkTreeIter* gtk_iter, const Glib::ustring &name)const
+KeyframeTreeStore::dump_iterator(const GtkTreeIter* /*gtk_iter*/, const Glib::ustring &/*name*/)const
 {
 #if 0
 	if(!gtk_iter)
@@ -345,6 +346,7 @@ KeyframeTreeStore::set_value_impl(const Gtk::TreeModel::iterator& row, int colum
 				// Bad old delta
 				return;
 			}
+			// row(row) on the next line is bad - don't use it, because it leaves 'row' uninitialised
 			//Gtk::TreeModel::iterator row(row);
 			//row++;
 			//if(!row)return;
