@@ -2,10 +2,11 @@
 /*!	\file layeractionmanager.cpp
 **	\brief Template File
 **
-**	$Id: layeractionmanager.cpp 479 2007-04-18 10:37:40Z dooglus $
+**	$Id: layeractionmanager.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -301,7 +302,7 @@ LayerActionManager::refresh()
 		}
 	}
 
-	ui_info="<ui><menubar action='menu-main'><menu action='menu-layer'>"+ui_info+"<separator/><menuitem action='cut' /><menuitem action='copy' /><menuitem action='paste' /><separator/></menu></menubar></ui>";
+	ui_info="<ui><popup action='menu-main'><menu action='menu-layer'>"+ui_info+"<separator/><menuitem action='cut' /><menuitem action='copy' /><menuitem action='paste' /><separator/></menu></popup></ui>";
 	popup_id_=get_ui_manager()->add_ui_from_string(ui_info);
 #ifdef ONE_ACTION_GROUP
 #else
@@ -432,7 +433,7 @@ LayerActionManager::amount_inc()
 	while(!layer_list.empty())
 	{
 		ValueBase value(layer_list.front()->get_param("amount"));
-		if(value.same_as(Real()))
+		if(value.same_type_as(Real()))
 		{
 			get_canvas_interface()->change_value(synfigapp::ValueDesc(layer_list.front(),"amount"),value.get(Real())+adjust);
 		}
@@ -456,7 +457,7 @@ LayerActionManager::amount_dec()
 	while(!layer_list.empty())
 	{
 		ValueBase value(layer_list.front()->get_param("amount"));
-		if(value.same_as(Real()))
+		if(value.same_type_as(Real()))
 		{
 			get_canvas_interface()->change_value(synfigapp::ValueDesc(layer_list.front(),"amount"),value.get(Real())+adjust);
 		}
