@@ -2,7 +2,7 @@
 /*!	\file layerparamtreestore.cpp
 **	\brief Template File
 **
-**	$Id: layerparamtreestore.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: layerparamtreestore.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -400,8 +400,9 @@ LayerParamTreeStore::rebuild()
 		}
 		if(value_desc.get_value_type()==ValueBase::TYPE_CANVAS)
 		{
-			changed_connection_list.push_back(
-				value_desc.get_value().get(Canvas::Handle())->signal_changed().connect(
+			Canvas::Handle canvas_handle = value_desc.get_value().get(Canvas::Handle());
+			if(canvas_handle) changed_connection_list.push_back(
+				canvas_handle->signal_changed().connect(
 					sigc::mem_fun(
 						this,
 						&LayerParamTreeStore::changed
@@ -518,43 +519,43 @@ LayerParamTreeStore::set_row(Gtk::TreeRow row,synfigapp::ValueDesc value_desc)
 }
 
 void
-LayerParamTreeStore::on_value_node_added(ValueNode::Handle value_node)
+LayerParamTreeStore::on_value_node_added(ValueNode::Handle /*value_node*/)
 {
 //	queue_refresh();
 }
 
 void
-LayerParamTreeStore::on_value_node_deleted(etl::handle<ValueNode> value_node)
+LayerParamTreeStore::on_value_node_deleted(etl::handle<ValueNode> /*value_node*/)
 {
 //	queue_refresh();
 }
 
 void
-LayerParamTreeStore::on_value_node_child_added(synfig::ValueNode::Handle value_node,synfig::ValueNode::Handle child)
+LayerParamTreeStore::on_value_node_child_added(synfig::ValueNode::Handle /*value_node*/,synfig::ValueNode::Handle /*child*/)
 {
 	queue_rebuild();
 }
 
 void
-LayerParamTreeStore::on_value_node_child_removed(synfig::ValueNode::Handle value_node,synfig::ValueNode::Handle child)
+LayerParamTreeStore::on_value_node_child_removed(synfig::ValueNode::Handle /*value_node*/,synfig::ValueNode::Handle /*child*/)
 {
 	rebuild();
 }
 
 void
-LayerParamTreeStore::on_value_node_changed(etl::handle<ValueNode> value_node)
+LayerParamTreeStore::on_value_node_changed(etl::handle<ValueNode> /*value_node*/)
 {
 	queue_refresh();
 }
 
 void
-LayerParamTreeStore::on_value_node_replaced(synfig::ValueNode::Handle replaced_value_node,synfig::ValueNode::Handle new_value_node)
+LayerParamTreeStore::on_value_node_replaced(synfig::ValueNode::Handle /*replaced_value_node*/,synfig::ValueNode::Handle /*new_value_node*/)
 {
 	queue_rebuild();
 }
 
 void
-LayerParamTreeStore::on_layer_param_changed(synfig::Layer::Handle handle,synfig::String param_name)
+LayerParamTreeStore::on_layer_param_changed(synfig::Layer::Handle /*handle*/,synfig::String /*param_name*/)
 {
 	queue_refresh();
 }
