@@ -2,7 +2,7 @@
 /*!	\file layertree.cpp
 **	\brief Template File
 **
-**	$Id: layertree.cpp 358 2007-03-19 16:11:31Z dooglus $
+**	$Id: layertree.cpp 578 2007-09-03 19:13:34Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -648,7 +648,7 @@ LayerTree::on_selection_changed()
 	button_duplicate->set_sensitive(true);
 	button_delete->set_sensitive(true);
 
-	if(layer_list.size()==1 && (*layer_list.begin())->get_param("amount").is_valid()&& (*layer_list.begin())->get_param("amount").same_as(Real()))
+	if(layer_list.size()==1 && (*layer_list.begin())->get_param("amount").is_valid()&& (*layer_list.begin())->get_param("amount").same_type_as(Real()))
 	{
 		quick_layer=*layer_list.begin();
 	}
