@@ -2,10 +2,11 @@
 /*!	\file gtkmm/main.cpp
 **	\brief Synfig Studio Entrypoint
 **
-**	$Id: main.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: main.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -116,7 +117,7 @@ int main(int argc, char **argv)
 		throw;
 	}
 
-	std::cerr<<"Application appears to have terminated successfuly"<<std::endl;
+	std::cerr<<"Application appears to have terminated successfully"<<std::endl;
 
 	return 0;
 }
