@@ -2,7 +2,7 @@
 /*!	\file metadatatreestore.cpp
 **	\brief Template File
 **
-**	$Id: metadatatreestore.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: metadatatreestore.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -79,7 +79,7 @@ MetaDataTreeStore::create(etl::loose_handle<synfigapp::CanvasInterface> canvas_i
 }
 
 void
-MetaDataTreeStore::meta_data_changed(synfig::String key)
+MetaDataTreeStore::meta_data_changed(synfig::String /*key*/)
 {
 	rebuild();
 }
