@@ -2,10 +2,11 @@
 /*!	\file onemoment.cpp
 **	\brief writeme
 **
-**	$Id: onemoment.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: onemoment.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -81,9 +82,9 @@ using namespace studio;
 
 /* === M E T H O D S ======================================================= */
 
-OneMoment::OneMoment():	Gtk::Window(Gtk::WINDOW_POPUP)
+OneMoment::OneMoment():
+	Gtk::Window(getenv("SYNFIG_DISABLE_POPUP_WINDOWS") ? Gtk::WINDOW_TOPLEVEL : Gtk::WINDOW_POPUP)
 {
-
 	// Create the Copyright Label
 	Gtk::Label *label = manage(new class Gtk::Label(_("One Moment, Please...")));
 
