@@ -2,10 +2,11 @@
 /*!	\file preview.cpp
 **	\brief Preview implementation file
 **
-**	$Id: preview.cpp 466 2007-04-12 17:50:38Z dooglus $
+**	$Id: preview.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -104,7 +105,7 @@ public:
 		return false;
 	}
 
-	virtual bool start_frame(ProgressCallback *cb=NULL)
+	virtual bool start_frame(ProgressCallback */*cb*/=NULL)
 	{
 		return true;
 	}
@@ -514,7 +515,7 @@ void studio::Widget_Preview::preview_draw()
 	draw_area.queue_draw();//on_expose_event();
 }
 
-bool studio::Widget_Preview::redraw(GdkEventExpose *heh)
+bool studio::Widget_Preview::redraw(GdkEventExpose */*heh*/)
 {
 	//And render the drawing area
 	Glib::RefPtr<Gdk::Pixbuf> pxnew, px = currentbuf;
