@@ -2,10 +2,11 @@
 /*!	\file gtkmm/renddesc.cpp
 **	\brief Template File
 **
-**	$Id: renddesc.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: renddesc.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -36,7 +37,7 @@
 #include <gtkmm/box.h>
 #include <ETL/misc>
 #include <synfig/general.h>
-//#include <gtkmm/seperator.h>
+//#include <gtkmm/separator.h>
 
 #endif
 
@@ -81,12 +82,12 @@ Widget_RendDesc::Widget_RendDesc():
 	Gtk::Notebook(),
 	adjustment_width(1,1,SYNFIG_MAX_PIXEL_WIDTH),
 	adjustment_height(1,1,SYNFIG_MAX_PIXEL_HEIGHT),
-	adjustment_xres(0,0,10000000),
-	adjustment_yres(0,0,10000000),
-	adjustment_phy_width(0,0,10000000),
-	adjustment_phy_height(0,0,10000000),
-	adjustment_fps(0,0,10000000),
-	adjustment_span(0,0,10000000)
+	adjustment_xres(0,0.0000000001,10000000),
+	adjustment_yres(0,0.0000000001,10000000),
+	adjustment_phy_width(0,0.0000000001,10000000),
+	adjustment_phy_height(0,0.0000000001,10000000),
+	adjustment_fps(0,0.0000000001,10000000),
+	adjustment_span(0,0.0000000001,10000000)
 {
 	update_lock=0;
 
