@@ -2,10 +2,11 @@
 /*!	\file gtkmm/render.cpp
 **	\brief Template File
 **
-**	$Id: render.cpp 349 2007-03-16 18:32:05Z dooglus $
+**	$Id: render.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -177,16 +178,7 @@ RenderSettings::RenderSettings(Gtk::Window& parent,handle<synfigapp::CanvasInter
 	toggle_single_frame.set_active(true);
 	widget_rend_desc.disable_time_section();
 
-
-	try
-	{
-		entry_filename.set_text(Glib::build_filename(Glib::get_home_dir(),Glib::ustring("Desktop")+ETL_DIRECTORY_SEPERATOR+Glib::ustring("output.png")));
-	}
-	catch(...)
-	{
-		synfig::warning("Averted crash!");
-		entry_filename.set_text("output.png");
-	}
+	set_entry_filename();
 
 	get_vbox()->show_all();
 }
@@ -195,6 +187,37 @@ RenderSettings::~RenderSettings()
 {
 }
 
+void
+RenderSettings::set_entry_filename()
+{
+	String filename(canvas_interface_->get_canvas()->get_file_name());
+
+	// if the basename of the filename has an extension, remove it
+	String base = basename(filename);
+	if(find(base.begin(),base.end(),'.')!=base.end())
+		filename = String(filename.begin(), filename.begin()+filename.find_last_of('.'));
+
+	// if this isn't the root canvas, append (<canvasname>) to the filename
+	etl::handle<synfig::Canvas> canvas = canvas_interface_->get_canvas();
+	if (!canvas->is_root())
+		if(canvas->get_name().empty())
+			filename+=" ("+canvas->get_id()+')';
+		else
+			filename+=" ("+canvas->get_name()+')';
+
+	filename += ".png";
+
+	try
+	{
+		entry_filename.set_text((filename));
+	}
+	catch(...)
+	{
+		synfig::warning("Averted crash!");
+		entry_filename.set_text("output.png");
+	}
+}
+
 void
 RenderSettings::on_rend_desc_changed()
 {
@@ -211,7 +234,7 @@ void
 RenderSettings::on_choose_pressed()
 {
 	String filename=entry_filename.get_text();
-	if(App::dialog_saveas_file("Save Render As",filename))
+	if(App::dialog_save_file("Save Render As",filename))
 		entry_filename.set_text(filename);
 }
 
