@@ -2,7 +2,7 @@
 /*!	\file renderer_bbox.cpp
 **	\brief Template File
 **
-**	$Id: renderer_bbox.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: renderer_bbox.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -66,7 +66,7 @@ Renderer_BBox::get_bbox()
 void
 Renderer_BBox::render_vfunc(
 	const Glib::RefPtr<Gdk::Drawable>& drawable,
-	const Gdk::Rectangle& expose_area
+	const Gdk::Rectangle& /*expose_area*/
 )
 {
 	assert(get_work_area());
