@@ -2,10 +2,11 @@
 /*!	\file renderer_canvas.cpp
 **	\brief Template File
 **
-**	$Id: renderer_canvas.cpp 475 2007-04-18 09:47:41Z dooglus $
+**	$Id: renderer_canvas.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -91,7 +92,7 @@ Renderer_Canvas::get_rendering()const
 void
 Renderer_Canvas::render_vfunc(
 	const Glib::RefPtr<Gdk::Drawable>& drawable,
-	const Gdk::Rectangle& expose_area
+	const Gdk::Rectangle& /*expose_area*/
 )
 {
 	assert(get_work_area());
