@@ -2,7 +2,7 @@
 /*!	\file renderer_dragbox.cpp
 **	\brief Template File
 **
-**	$Id: renderer_dragbox.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: renderer_dragbox.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -76,7 +76,7 @@ Renderer_Dragbox::get_enabled_vfunc()const
 void
 Renderer_Dragbox::render_vfunc(
 	const Glib::RefPtr<Gdk::Drawable>& drawable,
-	const Gdk::Rectangle& expose_area
+	const Gdk::Rectangle& /*expose_area*/
 )
 {
 	assert(get_work_area());
