@@ -2,7 +2,7 @@
 /*!	\file renderer_grid.cpp
 **	\brief Template File
 **
-**	$Id: renderer_grid.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: renderer_grid.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -69,7 +69,7 @@ Renderer_Grid::get_grid_size()const
 void
 Renderer_Grid::render_vfunc(
 	const Glib::RefPtr<Gdk::Drawable>& drawable,
-	const Gdk::Rectangle& expose_area
+	const Gdk::Rectangle& /*expose_area*/
 )
 {
 	assert(get_work_area());
