@@ -2,7 +2,7 @@
 /*!	\file renderer_guides.cpp
 **	\brief Template File
 **
-**	$Id: renderer_guides.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: renderer_guides.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -191,7 +191,7 @@ Renderer_Guides::event_vfunc(GdkEvent* event)
 void
 Renderer_Guides::render_vfunc(
 	const Glib::RefPtr<Gdk::Drawable>& drawable,
-	const Gdk::Rectangle& expose_area
+	const Gdk::Rectangle& /*expose_area*/
 )
 {
 	assert(get_work_area());
