@@ -2,10 +2,11 @@
 /*!	\file renderer_timecode.cpp
 **	\brief Template File
 **
-**	$Id: renderer_timecode.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: renderer_timecode.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -75,7 +76,7 @@ Renderer_Timecode::get_grid_size()const
 void
 Renderer_Timecode::render_vfunc(
 	const Glib::RefPtr<Gdk::Drawable>& drawable,
-	const Gdk::Rectangle& expose_area
+	const Gdk::Rectangle& /*expose_area*/
 )
 {
 	assert(get_work_area());
@@ -146,10 +147,15 @@ Renderer_Timecode::render_vfunc(
 		gc->set_rgb_fg_color(Gdk::Color("#5f0000"));
 		try
 		{
+			int w, h;
 			layout->set_text(canvas->keyframe_list().find(cur_time)->get_description());
+			layout->get_size(w, h);
+			get_work_area()->timecode_width = int(w*1.0/Pango::SCALE);
+			get_work_area()->timecode_height = int(h*1.0/Pango::SCALE);
 		}
 		catch(synfig::Exception::NotFound)
 		{
+			get_work_area()->timecode_width = get_work_area()->timecode_height = 0;
 			return;
 		}
 		catch(...) {
