@@ -2,10 +2,11 @@
 /*!	\file state_bline.cpp
 **	\brief Template File
 **
-**	$Id: state_bline.cpp 370 2007-03-23 02:39:21Z pabs $
+**	$Id: state_bline.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -113,6 +114,7 @@ class studio::StateBLine_Context : public sigc::trackable
 	Gtk::CheckButton checkbutton_layer_region;
 	Gtk::CheckButton checkbutton_layer_bline;
 	Gtk::CheckButton checkbutton_layer_curve_gradient;
+	Gtk::CheckButton checkbutton_layer_link_offsets;
 	Gtk::CheckButton checkbutton_auto_export;
 	Gtk::Button button_make;
 	Gtk::Button button_clear;
@@ -149,6 +151,9 @@ public:
 	bool get_layer_curve_gradient_flag()const { return checkbutton_layer_curve_gradient.get_active(); }
 	void set_layer_curve_gradient_flag(bool x) { return checkbutton_layer_curve_gradient.set_active(x); }
 
+	bool get_layer_link_offsets_flag()const { return checkbutton_layer_link_offsets.get_active(); }
+	void set_layer_link_offsets_flag(bool x) { return checkbutton_layer_link_offsets.set_active(x); }
+
 	Real get_feather() const { return adj_feather.get_value(); }
 	void set_feather(Real x) { return adj_feather.set_value(x); }
 	synfig::String get_id()const { return entry_id.get_text(); }
@@ -163,7 +168,7 @@ public:
 	Smach::event_result event_mouse_motion_handler(const Smach::event& x);
 	Smach::event_result event_refresh_tool_options(const Smach::event& x);
 
-	Smach::event_result event_hijack(const Smach::event& x) { return Smach::RESULT_ACCEPT; }
+	Smach::event_result event_hijack(const Smach::event& /*x*/) { return Smach::RESULT_ACCEPT; }
 
 	void refresh_tool_options();
 
@@ -186,10 +191,10 @@ public:
 	bool run_();
 	bool run();
 
-	bool no_egress_on_selection_change;
-	Smach::event_result event_layer_selection_changed_handler(const Smach::event& x)
+	bool egress_on_selection_change;
+	Smach::event_result event_layer_selection_changed_handler(const Smach::event& /*x*/)
 	{
-		if(!no_egress_on_selection_change)
+		if(egress_on_selection_change)
 			throw Smach::egress_exception();
 		return Smach::RESULT_OK;
 	}
@@ -237,6 +242,11 @@ StateBLine_Context::load_settings()
 	else
 		set_layer_curve_gradient_flag(false);
 
+	if(settings.get_value("bline.layer_link_offsets",value) && value=="0")
+		set_layer_link_offsets_flag(false);
+	else
+		set_layer_link_offsets_flag(true);
+
 	if(settings.get_value("bline.auto_export",value) && value=="1")
 		set_auto_export_flag(true);
 	else
@@ -263,6 +273,7 @@ StateBLine_Context::save_settings()
 	settings.set_value("bline.layer_bline",get_layer_bline_flag()?"1":"0");
 	settings.set_value("bline.layer_region",get_layer_region_flag()?"1":"0");
 	settings.set_value("bline.layer_curve_gradient",get_layer_curve_gradient_flag()?"1":"0");
+	settings.set_value("bline.layer_link_offsets",get_layer_link_offsets_flag()?"1":"0");
 	settings.set_value("bline.auto_export",get_auto_export_flag()?"1":"0");
 	settings.set_value("bline.id",get_id().c_str());
 	settings.set_value("bline.feather",strprintf("%f",get_feather()));
@@ -324,13 +335,14 @@ StateBLine_Context::StateBLine_Context(CanvasView* canvas_view):
 	canvas_view_(canvas_view),
 	is_working(*canvas_view),
 	loop_(false),
-	prev_workarea_layer_status_(get_work_area()->allow_layer_clicks),
+	prev_workarea_layer_status_(get_work_area()->get_allow_layer_clicks()),
 	duckmatic_push(get_work_area()),
 	settings(synfigapp::Main::get_selected_input_device()->settings()),
 	entry_id(),
 	checkbutton_layer_region(_("Fill")),
 	checkbutton_layer_bline(_("Outline")),
 	checkbutton_layer_curve_gradient(_("Gradient")),
+	checkbutton_layer_link_offsets(_("Link Offsets")),
 	checkbutton_auto_export(_("Auto Export")),
 	button_make(_("Make")),
 	button_clear(_("Clear")),
@@ -338,18 +350,19 @@ StateBLine_Context::StateBLine_Context(CanvasView* canvas_view):
 	spin_feather(adj_feather,0.01,4)
 {
 	depth=-1;
-	no_egress_on_selection_change=false;
+	egress_on_selection_change=true;
 	load_settings();
 
 	// Set up the tool options dialog
 	//options_table.attach(*manage(new Gtk::Label(_("BLine Tool"))), 0, 2, 0, 1, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(entry_id, 0, 2, 1, 2, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_region, 0, 2, 2, 3, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_bline, 0, 2, 3, 4, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_curve_gradient, 0, 2, 4, 5, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(entry_id,								0, 2,  1,  2, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_region,				0, 2,  2,  3, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_bline,				0, 2,  3,  4, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_curve_gradient,		0, 2,  4,  5, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_link_offsets,		0, 2,  5,  6, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_auto_export,				0, 2,  6,  7, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 	options_table.attach(*manage(new Gtk::Label(_("Feather"))), 0, 1, 10, 11, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(spin_feather, 1, 2, 10, 11, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_auto_export, 0, 2, 11, 12, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(spin_feather,							1, 2, 10, 11, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 	//options_table.attach(button_make, 0, 2, 5, 6, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 	//button_make.signal_pressed().connect(sigc::mem_fun(*this,&StateBLine_Context::run));
 	options_table.show_all();
@@ -357,7 +370,7 @@ StateBLine_Context::StateBLine_Context(CanvasView* canvas_view):
 	App::dialog_tool_options->present();
 
 	// Turn off layer clicking
-	get_work_area()->allow_layer_clicks=false;
+	get_work_area()->set_allow_layer_clicks(false);
 
 	// clear out the ducks
 	get_work_area()->clear_ducks();
@@ -409,7 +422,7 @@ StateBLine_Context::refresh_tool_options()
 }
 
 Smach::event_result
-StateBLine_Context::event_refresh_tool_options(const Smach::event& x)
+StateBLine_Context::event_refresh_tool_options(const Smach::event& /*x*/)
 {
 	refresh_tool_options();
 	return Smach::RESULT_ACCEPT;
@@ -425,7 +438,7 @@ StateBLine_Context::~StateBLine_Context()
 	get_canvas_view()->work_area->reset_cursor();
 
 	// Restore layer clicking
-	get_work_area()->allow_layer_clicks=prev_workarea_layer_status_;
+	get_work_area()->set_allow_layer_clicks(prev_workarea_layer_status_);
 
 	// Enable the time bar
 	get_canvas_view()->set_sensitive_timebar(true);
@@ -442,7 +455,7 @@ StateBLine_Context::~StateBLine_Context()
 }
 
 Smach::event_result
-StateBLine_Context::event_stop_handler(const Smach::event& x)
+StateBLine_Context::event_stop_handler(const Smach::event& /*x*/)
 {
 	synfig::info("STATE RotoBLine: Received Stop Event");
 //	run();
@@ -453,7 +466,7 @@ StateBLine_Context::event_stop_handler(const Smach::event& x)
 }
 
 Smach::event_result
-StateBLine_Context::event_refresh_handler(const Smach::event& x)
+StateBLine_Context::event_refresh_handler(const Smach::event& /*x*/)
 {
 	synfig::info("STATE RotoBLine: Received Refresh Event");
 	refresh_ducks();
@@ -533,9 +546,11 @@ StateBLine_Context::run_()
 		}
 
 		ValueNode_BLine::Handle value_node_bline(ValueNode_BLine::create(new_list));
-
 		assert(value_node_bline);
 
+		ValueNode_Const::Handle value_node_offset(ValueNode_Const::create(Vector()));
+		assert(value_node_offset);
+
 		// Set the looping flag
 		value_node_bline->set_loop(loop_);
 
@@ -575,8 +590,8 @@ StateBLine_Context::run_()
 			synfigapp::PushMode push_mode(get_canvas_interface(),synfigapp::MODE_NORMAL);
 
 			Layer::Handle layer(get_canvas_interface()->add_layer_to("region",canvas,depth));
-			layer_selection.push_back(layer);
 			assert(layer);
+			layer_selection.push_back(layer);
 			layer->set_description(get_id()+_(" Region"));
 			get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
 
@@ -589,24 +604,49 @@ StateBLine_Context::run_()
 			if(get_layer_bline_flag())
 				layer->set_param("color",synfigapp::Main::get_background_color());
 
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
-
-			assert(action);
-
-			action->set_param("canvas",get_canvas());
-			action->set_param("canvas_interface",get_canvas_interface());
-			action->set_param("layer",layer);
-			if(!action->set_param("param",String("bline")))
-				synfig::error("LayerParamConnect didn't like \"param\"");
-			if(!action->set_param("value_node",ValueNode::Handle(value_node_bline)))
-				synfig::error("LayerParamConnect didn't like \"value_node\"");
-
-			if(!get_canvas_interface()->get_instance()->perform_action(action))
+			// I don't know if it's safe to reuse the same layer_param_connect action, so I'm
+			// using 2 separate ones.
 			{
-				//get_canvas_view()->get_ui_interface()->error(_("Unable to create Region layer"));
-				group.cancel();
-				throw String(_("Unable to create Region layer"));
-				return false;
+				synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+				assert(action);
+
+				action->set_param("canvas",get_canvas());
+				action->set_param("canvas_interface",get_canvas_interface());
+				action->set_param("layer",layer);
+				if(!action->set_param("param",String("bline")))
+					synfig::error("LayerParamConnect didn't like \"param\"");
+				if(!action->set_param("value_node",ValueNode::Handle(value_node_bline)))
+					synfig::error("LayerParamConnect didn't like \"value_node\"");
+
+				if(!get_canvas_interface()->get_instance()->perform_action(action))
+				{
+					//get_canvas_view()->get_ui_interface()->error(_("Unable to create Region layer"));
+					group.cancel();
+					throw String(_("Unable to create Region layer"));
+					return false;
+				}
+			}
+
+			if (get_layer_link_offsets_flag())
+			{
+				synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+				assert(action);
+
+				action->set_param("canvas",get_canvas());
+				action->set_param("canvas_interface",get_canvas_interface());
+				action->set_param("layer",layer);
+				if(!action->set_param("param",String("offset")))
+					synfig::error("LayerParamConnect didn't like \"param\"");
+				if(!action->set_param("value_node",ValueNode::Handle(value_node_offset)))
+					synfig::error("LayerParamConnect didn't like \"value_node\"");
+
+				if(!get_canvas_interface()->get_instance()->perform_action(action))
+				{
+					//get_canvas_view()->get_ui_interface()->error(_("Unable to create Region layer"));
+					group.cancel();
+					throw String(_("Unable to create Region layer"));
+					return false;
+				}
 			}
 		}
 
@@ -616,6 +656,7 @@ StateBLine_Context::run_()
 			synfigapp::PushMode push_mode(get_canvas_interface(),synfigapp::MODE_NORMAL);
 
 			Layer::Handle layer(get_canvas_interface()->add_layer_to("outline",canvas,depth));
+			assert(layer);
 			layer_selection.push_back(layer);
 			layer->set_description(get_id()+_(" Outline"));
 			get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
@@ -625,27 +666,47 @@ StateBLine_Context::run_()
 				get_canvas_interface()->signal_layer_param_changed()(layer,"feather");
 			}
 
-			assert(layer);
-
-
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
-
-			assert(action);
-
-			action->set_param("canvas",get_canvas());
-			action->set_param("canvas_interface",get_canvas_interface());
-			action->set_param("layer",layer);
-			if(!action->set_param("param",String("bline")))
-				synfig::error("LayerParamConnect didn't like \"param\"");
-			if(!action->set_param("value_node",ValueNode::Handle(value_node_bline)))
-				synfig::error("LayerParamConnect didn't like \"value_node\"");
-
-			if(!get_canvas_interface()->get_instance()->perform_action(action))
 			{
-				//get_canvas_view()->get_ui_interface()->error(_("Unable to create BLine layer"));
-				group.cancel();
-				throw String(_("Unable to create Outline layer"));
-				return false;
+				synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+				assert(action);
+
+				action->set_param("canvas",get_canvas());
+				action->set_param("canvas_interface",get_canvas_interface());
+				action->set_param("layer",layer);
+				if(!action->set_param("param",String("bline")))
+					synfig::error("LayerParamConnect didn't like \"param\"");
+				if(!action->set_param("value_node",ValueNode::Handle(value_node_bline)))
+					synfig::error("LayerParamConnect didn't like \"value_node\"");
+
+				if(!get_canvas_interface()->get_instance()->perform_action(action))
+				{
+					//get_canvas_view()->get_ui_interface()->error(_("Unable to create BLine layer"));
+					group.cancel();
+					throw String(_("Unable to create Outline layer"));
+					return false;
+				}
+			}
+
+			if (get_layer_link_offsets_flag())
+			{
+				synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+				assert(action);
+
+				action->set_param("canvas",get_canvas());
+				action->set_param("canvas_interface",get_canvas_interface());
+				action->set_param("layer",layer);
+				if(!action->set_param("param",String("offset")))
+					synfig::error("LayerParamConnect didn't like \"param\"");
+				if(!action->set_param("value_node",ValueNode::Handle(value_node_offset)))
+					synfig::error("LayerParamConnect didn't like \"value_node\"");
+
+				if(!get_canvas_interface()->get_instance()->perform_action(action))
+				{
+					//get_canvas_view()->get_ui_interface()->error(_("Unable to create BLine layer"));
+					group.cancel();
+					throw String(_("Unable to create Outline layer"));
+					return false;
+				}
 			}
 
 			/*if(get_layer_region_flag() && !get_auto_export_flag())
@@ -662,31 +723,52 @@ StateBLine_Context::run_()
 			synfigapp::PushMode push_mode(get_canvas_interface(),synfigapp::MODE_NORMAL);
 
 			Layer::Handle layer(get_canvas_interface()->add_layer_to("curve_gradient",canvas,depth));
+			assert(layer);
 			layer_selection.push_back(layer);
 			layer->set_description(get_id()+_(" Gradient"));
 			get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
 
-			assert(layer);
-
-
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
-
-			assert(action);
-
-			action->set_param("canvas",get_canvas());
-			action->set_param("canvas_interface",get_canvas_interface());
-			action->set_param("layer",layer);
-			if(!action->set_param("param",String("bline")))
-				synfig::error("LayerParamConnect didn't like \"param\"");
-			if(!action->set_param("value_node",ValueNode::Handle(value_node_bline)))
-				synfig::error("LayerParamConnect didn't like \"value_node\"");
-
-			if(!get_canvas_interface()->get_instance()->perform_action(action))
 			{
-				//get_canvas_view()->get_ui_interface()->error(_("Unable to create BLine layer"));
-				group.cancel();
-				throw String(_("Unable to create Gradient layer"));
-				return false;
+				synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+				assert(action);
+
+				action->set_param("canvas",get_canvas());
+				action->set_param("canvas_interface",get_canvas_interface());
+				action->set_param("layer",layer);
+				if(!action->set_param("param",String("bline")))
+					synfig::error("LayerParamConnect didn't like \"param\"");
+				if(!action->set_param("value_node",ValueNode::Handle(value_node_bline)))
+					synfig::error("LayerParamConnect didn't like \"value_node\"");
+
+				if(!get_canvas_interface()->get_instance()->perform_action(action))
+				{
+					//get_canvas_view()->get_ui_interface()->error(_("Unable to create BLine layer"));
+					group.cancel();
+					throw String(_("Unable to create Gradient layer"));
+					return false;
+				}
+			}
+
+			if (get_layer_link_offsets_flag())
+			{
+				synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+				assert(action);
+
+				action->set_param("canvas",get_canvas());
+				action->set_param("canvas_interface",get_canvas_interface());
+				action->set_param("layer",layer);
+				if(!action->set_param("param",String("offset")))
+					synfig::error("LayerParamConnect didn't like \"param\"");
+				if(!action->set_param("value_node",ValueNode::Handle(value_node_offset)))
+					synfig::error("LayerParamConnect didn't like \"value_node\"");
+
+				if(!get_canvas_interface()->get_instance()->perform_action(action))
+				{
+					//get_canvas_view()->get_ui_interface()->error(_("Unable to create BLine layer"));
+					group.cancel();
+					throw String(_("Unable to create Gradient layer"));
+					return false;
+				}
 			}
 
 			/*if(get_layer_region_flag() && !get_auto_export_flag())
@@ -695,10 +777,10 @@ StateBLine_Context::run_()
 			}*/
 		}
 
-		no_egress_on_selection_change=true;
+		egress_on_selection_change=false;
 		get_canvas_interface()->get_selection_manager()->clear_selected_layers();
 		get_canvas_interface()->get_selection_manager()->set_selected_layers(layer_selection);
-		no_egress_on_selection_change=false;
+		egress_on_selection_change=true;
 
 		//if(finish_bline_dialog.get_region_flag() || finish_bline_dialog.get_bline_flag())
 		//	get_canvas_interface()->signal_dirty_preview()();
@@ -730,7 +812,7 @@ StateBLine_Context::event_mouse_motion_handler(const Smach::event& x)
 }
 
 Smach::event_result
-StateBLine_Context::event_mouse_release_handler(const Smach::event& x)
+StateBLine_Context::event_mouse_release_handler(const Smach::event& /*x*/)
 {
 	if(curr_duck)
 	{
