@@ -2,7 +2,7 @@
 /*!	\file state_eyedrop.cpp
 **	\brief Template File
 **
-**	$Id: state_eyedrop.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: state_eyedrop.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -109,7 +109,7 @@ StateEyedrop_Context::~StateEyedrop_Context()
 }
 
 Smach::event_result
-StateEyedrop_Context::event_stop_handler(const Smach::event& x)
+StateEyedrop_Context::event_stop_handler(const Smach::event& /*x*/)
 {
 	synfig::info("STATE EYEDROP: Received Stop Event");
 	throw Smach::egress_exception();
@@ -118,7 +118,7 @@ StateEyedrop_Context::event_stop_handler(const Smach::event& x)
 }
 
 Smach::event_result
-StateEyedrop_Context::event_refresh_handler(const Smach::event& x)
+StateEyedrop_Context::event_refresh_handler(const Smach::event& /*x*/)
 {
 	synfig::info("STATE EYEDROP: Received Refresh Event");
 	canvas_view->work_area->queue_render_preview();
