@@ -2,7 +2,7 @@
 /*!	\file state_fill.cpp
 **	\brief Template File
 **
-**	$Id: state_fill.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: state_fill.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -116,7 +116,7 @@ StateFill_Context::~StateFill_Context()
 }
 
 Smach::event_result
-StateFill_Context::event_stop_handler(const Smach::event& x)
+StateFill_Context::event_stop_handler(const Smach::event& /*x*/)
 {
 	synfig::info("STATE FILL: Received Stop Event");
 	throw Smach::egress_exception();
@@ -125,7 +125,7 @@ StateFill_Context::event_stop_handler(const Smach::event& x)
 }
 
 Smach::event_result
-StateFill_Context::event_refresh_handler(const Smach::event& x)
+StateFill_Context::event_refresh_handler(const Smach::event& /*x*/)
 {
 	synfig::info("STATE FILL: Received Refresh Event");
 	canvas_view->work_area->queue_render_preview();
