@@ -2,7 +2,7 @@
 /*!	\file state_gradient.cpp
 **	\brief Template File
 **
-**	$Id: state_gradient.cpp 370 2007-03-23 02:39:21Z pabs $
+**	$Id: state_gradient.cpp 680 2007-09-16 19:28:39Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -133,10 +133,10 @@ public:
 	void increment_id();
 
 	void make_gradient(const Point& p1, const Point& p2);
-	bool no_egress_on_selection_change;
-	Smach::event_result event_layer_selection_changed_handler(const Smach::event& x)
+	bool egress_on_selection_change;
+	Smach::event_result event_layer_selection_changed_handler(const Smach::event& /*x*/)
 	{
-		if(!no_egress_on_selection_change)
+		if(egress_on_selection_change)
 			throw Smach::egress_exception();
 		return Smach::RESULT_OK;
 	}
@@ -245,10 +245,10 @@ StateGradient_Context::StateGradient_Context(CanvasView* canvas_view):
 	is_working(*canvas_view),
 	duckmatic_push(get_work_area()),
 	settings(synfigapp::Main::get_selected_input_device()->settings()),
-	prev_workarea_layer_status_(get_work_area()->allow_layer_clicks),
+	prev_workarea_layer_status_(get_work_area()->get_allow_layer_clicks()),
 	entry_id()
 {
-	no_egress_on_selection_change=false;
+	egress_on_selection_change=true;
 	// Set up the tool options dialog
 	///options_table.attach(*manage(new Gtk::Label(_("Gradient Tool"))), 0, 2, 0, 1, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 	options_table.attach(entry_id, 0, 2, 1, 2, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
@@ -277,7 +277,7 @@ StateGradient_Context::StateGradient_Context(CanvasView* canvas_view):
 
 
 	// Turn off layer clicking
-	get_work_area()->allow_layer_clicks=false;
+	get_work_area()->set_allow_layer_clicks(false);
 
 	get_canvas_view()->work_area->set_cursor(Gdk::CROSSHAIR);
 
@@ -311,7 +311,7 @@ StateGradient_Context::refresh_tool_options()
 }
 
 Smach::event_result
-StateGradient_Context::event_refresh_tool_options(const Smach::event& x)
+StateGradient_Context::event_refresh_tool_options(const Smach::event& /*x*/)
 {
 	refresh_tool_options();
 	return Smach::RESULT_ACCEPT;
@@ -322,8 +322,8 @@ StateGradient_Context::~StateGradient_Context()
 	save_settings();
 
 	// Restore layer clicking
-//	get_work_area()->allow_layer_clicks=prev_workarea_layer_status_;
-	get_work_area()->allow_layer_clicks=true;
+//	get_work_area()->set_allow_layer_clicks(prev_workarea_layer_status_);
+	get_work_area()->set_allow_layer_clicks(true);
 	get_canvas_view()->work_area->reset_cursor();
 
 	App::dialog_tool_options->clear();
@@ -345,13 +345,13 @@ StateGradient_Context::~StateGradient_Context()
 }
 
 Smach::event_result
-StateGradient_Context::event_stop_handler(const Smach::event& x)
+StateGradient_Context::event_stop_handler(const Smach::event& /*x*/)
 {
 	throw Smach::egress_exception();
 }
 
 Smach::event_result
-StateGradient_Context::event_refresh_handler(const Smach::event& x)
+StateGradient_Context::event_refresh_handler(const Smach::event& /*x*/)
 {
 	refresh_ducks();
 	return Smach::RESULT_ACCEPT;
@@ -429,10 +429,10 @@ StateGradient_Context::make_gradient(const Point& _p1, const Point& _p2)
 	layer->set_description(get_id());
 	get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
 
-	no_egress_on_selection_change=true;
+	egress_on_selection_change=false;
 	get_canvas_interface()->get_selection_manager()->clear_selected_layers();
 	get_canvas_interface()->get_selection_manager()->set_selected_layer(layer);
-	no_egress_on_selection_change=false;
+	egress_on_selection_change=true;
 
 	reset();
 	increment_id();
