@@ -2,7 +2,7 @@
 /*!	\file state_polygon.cpp
 **	\brief Template File
 **
-**	$Id: state_polygon.cpp 370 2007-03-23 02:39:21Z pabs $
+**	$Id: state_polygon.cpp 680 2007-09-16 19:28:39Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -118,10 +118,10 @@ public:
 	void save_settings();
 	void reset();
 	void increment_id();
-	bool no_egress_on_selection_change;
-	Smach::event_result event_layer_selection_changed_handler(const Smach::event& x)
+	bool egress_on_selection_change;
+	Smach::event_result event_layer_selection_changed_handler(const Smach::event& /*x*/)
 	{
-		if(!no_egress_on_selection_change)
+		if(egress_on_selection_change)
 			throw Smach::egress_exception();
 		return Smach::RESULT_OK;
 	}
@@ -215,13 +215,13 @@ StatePolygon_Context::increment_id()
 StatePolygon_Context::StatePolygon_Context(CanvasView* canvas_view):
 	canvas_view_(canvas_view),
 	is_working(*canvas_view),
-	prev_workarea_layer_status_(get_work_area()->allow_layer_clicks),
+	prev_workarea_layer_status_(get_work_area()->get_allow_layer_clicks()),
 	duckmatic_push(get_work_area()),
 	settings(synfigapp::Main::get_selected_input_device()->settings()),
 	entry_id(),
 	button_make(_("Make"))
 {
-	no_egress_on_selection_change=false;
+	egress_on_selection_change=true;
 	load_settings();
 
 	// Set up the tool options dialog
@@ -235,7 +235,7 @@ StatePolygon_Context::StatePolygon_Context(CanvasView* canvas_view):
 
 
 	// Turn off layer clicking
-	get_work_area()->allow_layer_clicks=false;
+	get_work_area()->set_allow_layer_clicks(false);
 
 	// clear out the ducks
 	get_work_area()->clear_ducks();
@@ -289,7 +289,7 @@ StatePolygon_Context::refresh_tool_options()
 }
 
 Smach::event_result
-StatePolygon_Context::event_refresh_tool_options(const Smach::event& x)
+StatePolygon_Context::event_refresh_tool_options(const Smach::event& /*x*/)
 {
 	refresh_tool_options();
 	return Smach::RESULT_ACCEPT;
@@ -301,7 +301,7 @@ StatePolygon_Context::~StatePolygon_Context()
 
 	save_settings();
 	// Restore layer clicking
-	get_work_area()->allow_layer_clicks=prev_workarea_layer_status_;
+	get_work_area()->set_allow_layer_clicks(prev_workarea_layer_status_);
 
 	App::dialog_tool_options->clear();
 
@@ -320,7 +320,7 @@ StatePolygon_Context::~StatePolygon_Context()
 }
 
 Smach::event_result
-StatePolygon_Context::event_stop_handler(const Smach::event& x)
+StatePolygon_Context::event_stop_handler(const Smach::event& /*x*/)
 {
 	synfig::info("STATE RotoPolygon: Received Stop Event");
 	//throw Smach::egress_exception();
@@ -330,7 +330,7 @@ StatePolygon_Context::event_stop_handler(const Smach::event& x)
 }
 
 Smach::event_result
-StatePolygon_Context::event_refresh_handler(const Smach::event& x)
+StatePolygon_Context::event_refresh_handler(const Smach::event& /*x*/)
 {
 	synfig::info("STATE RotoPolygon: Received Refresh Event");
 	refresh_ducks();
@@ -390,10 +390,10 @@ StatePolygon_Context::run()
 					return;
 				}
 			}
-			no_egress_on_selection_change=true;
+			egress_on_selection_change=false;
 			get_canvas_interface()->get_selection_manager()->clear_selected_layers();
 			get_canvas_interface()->get_selection_manager()->set_selected_layer(layer);
-			no_egress_on_selection_change=false;
+			egress_on_selection_change=true;
 			//get_canvas_interface()->signal_dirty_preview()();
 		}
 /*
