@@ -2,7 +2,7 @@
 /*!	\file state_rectangle.cpp
 **	\brief Template File
 **
-**	$Id: state_rectangle.cpp 370 2007-03-23 02:39:21Z pabs $
+**	$Id: state_rectangle.cpp 680 2007-09-16 19:28:39Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -128,10 +128,10 @@ public:
 	void save_settings();
 	void reset();
 	void increment_id();
-	bool no_egress_on_selection_change;
-	Smach::event_result event_layer_selection_changed_handler(const Smach::event& x)
+	bool egress_on_selection_change;
+	Smach::event_result event_layer_selection_changed_handler(const Smach::event& /*x*/)
 	{
-		if(!no_egress_on_selection_change)
+		if(egress_on_selection_change)
 			throw Smach::egress_exception();
 		return Smach::RESULT_OK;
 	}
@@ -241,14 +241,14 @@ StateRectangle_Context::StateRectangle_Context(CanvasView* canvas_view):
 	canvas_view_(canvas_view),
 	is_working(*canvas_view),
 	duckmatic_push(get_work_area()),
-	prev_workarea_layer_status_(get_work_area()->allow_layer_clicks),
+	prev_workarea_layer_status_(get_work_area()->get_allow_layer_clicks()),
 	settings(synfigapp::Main::get_selected_input_device()->settings()),
 	entry_id(),
 	adj_expand(0,0,1,0.01,0.1),
 	spin_expand(adj_expand,0.1,3),
 	check_invert(_("Invert"))
 {
-	no_egress_on_selection_change=false;
+	egress_on_selection_change=true;
 	load_settings();
 
 	// Set up the tool options dialog
@@ -269,7 +269,7 @@ StateRectangle_Context::StateRectangle_Context(CanvasView* canvas_view):
 	App::dialog_tool_options->present();
 
 	// Turn off layer clicking
-	get_work_area()->allow_layer_clicks=false;
+	get_work_area()->set_allow_layer_clicks(false);
 
 	// clear out the ducks
 	get_work_area()->clear_ducks();
@@ -302,7 +302,7 @@ StateRectangle_Context::refresh_tool_options()
 }
 
 Smach::event_result
-StateRectangle_Context::event_refresh_tool_options(const Smach::event& x)
+StateRectangle_Context::event_refresh_tool_options(const Smach::event& /*x*/)
 {
 	refresh_tool_options();
 	return Smach::RESULT_ACCEPT;
@@ -313,7 +313,7 @@ StateRectangle_Context::~StateRectangle_Context()
 	save_settings();
 
 	// Restore layer clicking
-	get_work_area()->allow_layer_clicks = prev_workarea_layer_status_;
+	get_work_area()->set_allow_layer_clicks(prev_workarea_layer_status_);
 
 	get_canvas_view()->work_area->reset_cursor();
 
@@ -332,13 +332,13 @@ StateRectangle_Context::~StateRectangle_Context()
 }
 
 Smach::event_result
-StateRectangle_Context::event_stop_handler(const Smach::event& x)
+StateRectangle_Context::event_stop_handler(const Smach::event& /*x*/)
 {
 	throw Smach::egress_exception();
 }
 
 Smach::event_result
-StateRectangle_Context::event_refresh_handler(const Smach::event& x)
+StateRectangle_Context::event_refresh_handler(const Smach::event& /*x*/)
 {
 	refresh_ducks();
 	return Smach::RESULT_ACCEPT;
@@ -386,10 +386,10 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 	layer->set_description(get_id());
 	get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
 
-	no_egress_on_selection_change=true;
+	egress_on_selection_change=false;
 	get_canvas_interface()->get_selection_manager()->clear_selected_layers();
 	get_canvas_interface()->get_selection_manager()->set_selected_layer(layer);
-	no_egress_on_selection_change=false;
+	egress_on_selection_change=true;
 
 	//post clean up stuff...
 	reset();
