@@ -2,7 +2,7 @@
 /*!	\file state_rotate.cpp
 **	\brief Template File
 **
-**	$Id: state_rotate.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: state_rotate.cpp 672 2007-09-14 22:34:53Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -185,7 +185,7 @@ StateRotate_Context::StateRotate_Context(CanvasView* canvas_view):
 	//App::dialog_tool_options->set_widget(options_table);
 	App::dialog_tool_options->present();
 
-	get_work_area()->allow_layer_clicks=true;
+	get_work_area()->set_allow_layer_clicks(true);
 	get_work_area()->set_duck_dragger(duck_dragger_);
 
 //	get_canvas_view()->work_area->set_cursor(Gdk::CROSSHAIR);
@@ -207,7 +207,7 @@ StateRotate_Context::refresh_tool_options()
 }
 
 Smach::event_result
-StateRotate_Context::event_refresh_tool_options(const Smach::event& x)
+StateRotate_Context::event_refresh_tool_options(const Smach::event& /*x*/)
 {
 	refresh_tool_options();
 	return Smach::RESULT_ACCEPT;
