@@ -2,7 +2,7 @@
 /*!	\file state_scale.cpp
 **	\brief Template File
 **
-**	$Id: state_scale.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: state_scale.cpp 672 2007-09-14 22:34:53Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -170,7 +170,7 @@ StateScale_Context::StateScale_Context(CanvasView* canvas_view):
 	refresh_tool_options();
 	App::dialog_tool_options->present();
 
-	get_work_area()->allow_layer_clicks=true;
+	get_work_area()->set_allow_layer_clicks(true);
 	get_work_area()->set_duck_dragger(duck_dragger_);
 
 //	get_canvas_view()->work_area->set_cursor(Gdk::CROSSHAIR);
@@ -192,7 +192,7 @@ StateScale_Context::refresh_tool_options()
 }
 
 Smach::event_result
-StateScale_Context::event_refresh_tool_options(const Smach::event& x)
+StateScale_Context::event_refresh_tool_options(const Smach::event& /*x*/)
 {
 	refresh_tool_options();
 	return Smach::RESULT_ACCEPT;
