@@ -2,7 +2,7 @@
 /*!	\file state_sketch.cpp
 **	\brief Template File
 **
-**	$Id: state_sketch.cpp 370 2007-03-23 02:39:21Z pabs $
+**	$Id: state_sketch.cpp 672 2007-09-14 22:34:53Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -230,7 +230,7 @@ StateSketch_Context::StateSketch_Context(CanvasView* canvas_view):
 	action_group(Gtk::ActionGroup::create()),
 	canvas_view_(canvas_view),
 	is_working(*canvas_view),
-	prev_workarea_layer_status_(get_work_area()->allow_layer_clicks),
+	prev_workarea_layer_status_(get_work_area()->get_allow_layer_clicks()),
 	button_clear_sketch(_("Clear Sketch")),
 	button_undo_stroke(_("Undo Stroke")),
 	button_save_sketch(_("Save Sketch")),
@@ -333,12 +333,12 @@ StateSketch_Context::StateSketch_Context(CanvasView* canvas_view):
 	App::dialog_tool_options->present();
 
 	// Turn off layer clicking
-	get_work_area()->allow_layer_clicks=false;
+	get_work_area()->set_allow_layer_clicks(false);
 
 	get_canvas_view()->work_area->set_cursor(Gdk::PENCIL);
 
 	// Turn off duck clicking
-	get_work_area()->allow_duck_clicks=false;
+	get_work_area()->set_allow_duck_clicks(false);
 
 	// clear out the ducks
 	//get_work_area()->clear_ducks();
@@ -366,10 +366,10 @@ StateSketch_Context::~StateSketch_Context()
 	App::dialog_tool_options->clear();
 
 	// Restore layer clicking
-	get_work_area()->allow_layer_clicks=prev_workarea_layer_status_;
+	get_work_area()->set_allow_layer_clicks(prev_workarea_layer_status_);
 
 	// Restore duck clicking
-	get_work_area()->allow_duck_clicks=true;
+	get_work_area()->set_allow_duck_clicks(true);
 
 	// Enable the time bar
 	//get_canvas_view()->set_sensitive_timebar(true);
@@ -448,27 +448,27 @@ StateSketch_Context::refresh_tool_options()
 }
 
 Smach::event_result
-StateSketch_Context::event_refresh_tool_options(const Smach::event& x)
+StateSketch_Context::event_refresh_tool_options(const Smach::event& /*x*/)
 {
 	refresh_tool_options();
 	return Smach::RESULT_ACCEPT;
 }
 
 Smach::event_result
-StateSketch_Context::event_yield_tool_options(const Smach::event& x)
+StateSketch_Context::event_yield_tool_options(const Smach::event& /*x*/)
 {
 	yield_tool_options();
 	return Smach::RESULT_ACCEPT;
 }
 
 Smach::event_result
-StateSketch_Context::event_stop_handler(const Smach::event& x)
+StateSketch_Context::event_stop_handler(const Smach::event& /*x*/)
 {
 	throw Smach::egress_exception();
 }
 
 Smach::event_result
-StateSketch_Context::event_refresh_handler(const Smach::event& x)
+StateSketch_Context::event_refresh_handler(const Smach::event& /*x*/)
 {
 	return Smach::RESULT_ACCEPT;
 }
