@@ -2,7 +2,7 @@
 /*!	\file state_smoothmove.cpp
 **	\brief Template File
 **
-**	$Id: state_smoothmove.cpp 387 2007-03-26 00:02:46Z dooglus $
+**	$Id: state_smoothmove.cpp 672 2007-09-14 22:34:53Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -183,7 +183,7 @@ StateSmoothMove_Context::StateSmoothMove_Context(CanvasView* canvas_view):
 	//App::dialog_tool_options->set_widget(options_table);
 	App::dialog_tool_options->present();
 
-	get_work_area()->allow_layer_clicks=true;
+	get_work_area()->set_allow_layer_clicks(true);
 	get_work_area()->set_duck_dragger(duck_dragger_);
 
 	App::toolbox->refresh();
@@ -204,7 +204,7 @@ StateSmoothMove_Context::refresh_tool_options()
 }
 
 Smach::event_result
-StateSmoothMove_Context::event_refresh_tool_options(const Smach::event& x)
+StateSmoothMove_Context::event_refresh_tool_options(const Smach::event& /*x*/)
 {
 	refresh_tool_options();
 	return Smach::RESULT_ACCEPT;
