@@ -2,7 +2,7 @@
 /*!	\file state_stroke.cpp
 **	\brief Template File
 **
-**	$Id: state_stroke.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: state_stroke.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -144,19 +144,19 @@ StateStroke_Context::~StateStroke_Context()
 }
 
 Smach::event_result
-StateStroke_Context::event_refresh_tool_options(const Smach::event& x)
+StateStroke_Context::event_refresh_tool_options(const Smach::event& /*x*/)
 {
 	return Smach::RESULT_ACCEPT;
 }
 
 Smach::event_result
-StateStroke_Context::event_stop_handler(const Smach::event& x)
+StateStroke_Context::event_stop_handler(const Smach::event& /*x*/)
 {
 	throw Smach::pop_exception();
 }
 
 Smach::event_result
-StateStroke_Context::event_refresh_handler(const Smach::event& x)
+StateStroke_Context::event_refresh_handler(const Smach::event& /*x*/)
 {
 	return Smach::RESULT_ACCEPT;
 }
