@@ -2,7 +2,7 @@
 /*!	\file state_width.cpp
 **	\brief Template File
 **
-**	$Id: state_width.cpp 370 2007-03-23 02:39:21Z pabs $
+**	$Id: state_width.cpp 672 2007-09-14 22:34:53Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -208,8 +208,8 @@ StateWidth_Context::reset()
 StateWidth_Context::StateWidth_Context(CanvasView* canvas_view):
 	canvas_view_(canvas_view),
 	is_working(*canvas_view),
-	prev_workarea_layer_clicking(get_work_area()->allow_layer_clicks),
-	prev_workarea_duck_clicking(get_work_area()->allow_duck_clicks),
+	prev_workarea_layer_clicking(get_work_area()->get_allow_layer_clicks()),
+	prev_workarea_duck_clicking(get_work_area()->get_allow_duck_clicks()),
 	old_duckmask(get_work_area()->get_type_mask()),
 
 	settings(synfigapp::Main::get_selected_input_device()->settings()),
@@ -243,7 +243,7 @@ StateWidth_Context::StateWidth_Context(CanvasView* canvas_view):
 	App::dialog_tool_options->present();
 
 	// Turn off layer clicking
-	get_work_area()->allow_layer_clicks=false;
+	get_work_area()->set_allow_layer_clicks(false);
 
 	// clear out the ducks
 	//get_work_area()->clear_ducks();
@@ -278,7 +278,7 @@ StateWidth_Context::StateWidth_Context(CanvasView* canvas_view):
 	}
 
 	//Disable duck clicking for the maximum coolness :)
-	get_work_area()->allow_duck_clicks = false;
+	get_work_area()->set_allow_duck_clicks(false);
 	get_work_area()->set_type_mask((Duck::Type)((int)Duck::TYPE_WIDTH + (int)Duck::TYPE_RADIUS));
 
 	// Turn the mouse pointer to crosshairs
@@ -307,7 +307,7 @@ StateWidth_Context::refresh_tool_options()
 }
 
 Smach::event_result
-StateWidth_Context::event_refresh_tool_options(const Smach::event& x)
+StateWidth_Context::event_refresh_tool_options(const Smach::event& /*x*/)
 {
 	refresh_tool_options();
 	return Smach::RESULT_ACCEPT;
@@ -327,10 +327,10 @@ StateWidth_Context::~StateWidth_Context()
 	}
 
 	// Restore Duck clicking
-	get_work_area()->allow_duck_clicks = prev_workarea_duck_clicking;
+	get_work_area()->set_allow_duck_clicks(prev_workarea_duck_clicking);
 
 	// Restore layer clicking
-	get_work_area()->allow_layer_clicks = prev_workarea_layer_clicking;
+	get_work_area()->set_allow_layer_clicks(prev_workarea_layer_clicking);
 
 	// Restore the mouse pointer
 	get_work_area()->reset_cursor();
@@ -354,13 +354,13 @@ StateWidth_Context::~StateWidth_Context()
 }
 
 Smach::event_result
-StateWidth_Context::event_stop_handler(const Smach::event& x)
+StateWidth_Context::event_stop_handler(const Smach::event& /*x*/)
 {
 	throw Smach::egress_exception();
 }
 
 Smach::event_result
-StateWidth_Context::event_refresh_handler(const Smach::event& x)
+StateWidth_Context::event_refresh_handler(const Smach::event& /*x*/)
 {
 	refresh_ducks();
 	return Smach::RESULT_ACCEPT;
