@@ -2,7 +2,7 @@
 /*!	\file state_zoom.cpp
 **	\brief Zoom Toole Implementation File
 **
-**	$Id: state_zoom.cpp 370 2007-03-23 02:39:21Z pabs $
+**	$Id: state_zoom.cpp 672 2007-09-14 22:34:53Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -153,7 +153,7 @@ StateZoom_Context::reset()
 StateZoom_Context::StateZoom_Context(CanvasView* canvas_view):
 	canvas_view_(canvas_view),
 	is_working(*canvas_view),
-	prev_workarea_layer_status_(get_work_area()->allow_layer_clicks),
+	prev_workarea_layer_status_(get_work_area()->get_allow_layer_clicks()),
 	settings(synfigapp::Main::get_selected_input_device()->settings())
 {
 	// Set up the tool options dialog
@@ -167,7 +167,7 @@ StateZoom_Context::StateZoom_Context(CanvasView* canvas_view):
 	App::dialog_tool_options->present();
 
 	// Turn off layer clicking
-	get_work_area()->allow_layer_clicks=false;
+	get_work_area()->set_allow_layer_clicks(false);
 
 	// clear out the ducks
 	get_work_area()->clear_ducks(); //???
@@ -199,7 +199,7 @@ StateZoom_Context::refresh_tool_options()
 }
 
 Smach::event_result
-StateZoom_Context::event_refresh_tool_options(const Smach::event& x)
+StateZoom_Context::event_refresh_tool_options(const Smach::event& /*x*/)
 {
 	refresh_tool_options();
 	return Smach::RESULT_ACCEPT;
@@ -210,7 +210,7 @@ StateZoom_Context::~StateZoom_Context()
 	save_settings();
 
 	// Restore layer clicking
-	get_work_area()->allow_layer_clicks=prev_workarea_layer_status_;
+	get_work_area()->set_allow_layer_clicks(prev_workarea_layer_status_);
 	get_canvas_view()->work_area->reset_cursor();
 
 	App::dialog_tool_options->clear();
@@ -230,13 +230,13 @@ StateZoom_Context::~StateZoom_Context()
 }
 
 Smach::event_result
-StateZoom_Context::event_stop_handler(const Smach::event& x)
+StateZoom_Context::event_stop_handler(const Smach::event& /*x*/)
 {
 	throw Smach::egress_exception();
 }
 
 Smach::event_result
-StateZoom_Context::event_refresh_handler(const Smach::event& x)
+StateZoom_Context::event_refresh_handler(const Smach::event& /*x*/)
 {
 	return Smach::RESULT_ACCEPT;
 }
