@@ -2,10 +2,11 @@
 /*!	\file statemanager.cpp
 **	\brief Template File
 **
-**	$Id: statemanager.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: statemanager.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -79,12 +80,15 @@ StateManager::add_state(const Smach::state_base *state)
 {
 	String name(state->get_name());
 
+	Gtk::StockItem stock_item;
+	Gtk::Stock::lookup(Gtk::StockID("synfig-"+name),stock_item);
+
 	Glib::RefPtr<Gtk::Action> action(
 		Gtk::Action::create(
 			"state-"+name,
-			Gtk::StockID("synfig-"+name),
-			name,
-			name
+			stock_item.get_stock_id(),
+			stock_item.get_label(),
+			stock_item.get_label()
 		)
 	);
 	/*action->set_sensitive(false);*/
