@@ -2,10 +2,11 @@
 /*!	\file widget_canvaschooser.cpp
 **	\brief Template File
 **
-**	$Id: widget_canvaschooser.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: widget_canvaschooser.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -129,7 +130,21 @@ void
 Widget_CanvasChooser::chooser_menu()
 {
 	String canvas_name;
-	App::dialog_entry(_("Choose Canvas"),_("Enter the relative name of the canvas that you want"),canvas_name);
+
+	if (!App::dialog_entry(_("Choose Canvas"),_("Enter the relative name of the canvas that you want"),canvas_name))
+	{
+		// the user hit 'cancel', so set the parameter back to its previous value
+		set_value_(canvas);
+		return;
+	}
+
+	if (canvas_name == "")
+	{
+		App::dialog_error_blocking(_("Error"),_("No canvas name was specified"));
+		set_value_(canvas);
+		return;
+	}
+		
 	Canvas::Handle new_canvas;
 	try
 	{
