@@ -2,7 +2,7 @@
 /*!	\file widget_color.cpp
 **	\brief Template File
 **
-**	$Id: widget_color.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: widget_color.cpp 750 2007-09-25 08:33:54Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -45,11 +45,6 @@ using namespace studio;
 
 /* === M A C R O S ========================================================= */
 
-#define use_colorspace_gamma()	App::use_colorspace_gamma
-#define colorspace_gamma()	(2.2f)
-#define gamma_in(x)		((x>0)?pow((float)x,1.0f/colorspace_gamma()):-pow((float)-x,1.0f/colorspace_gamma()))
-#define gamma_out(x)	((x>0)?pow((float)x,colorspace_gamma()):-pow((float)-x,colorspace_gamma()))
-
 /* === G L O B A L S ======================================================= */
 
 /* === P R O C E D U R E S ================================================= */
@@ -185,7 +180,7 @@ Widget_Color::on_event(GdkEvent *event)
 }
 
 bool
-Widget_Color::redraw(GdkEventExpose*bleh)
+Widget_Color::redraw(GdkEventExpose */*bleh*/)
 {
 	//Glib::RefPtr<Gdk::GC> gc(Gdk::GC::create(get_window()));
 
