@@ -2,10 +2,11 @@
 /*!	\file widget_coloredit.cpp
 **	\brief Template File
 **
-**	$Id: widget_coloredit.cpp 419 2007-04-02 15:13:43Z dooglus $
+**	$Id: widget_coloredit.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -50,11 +51,6 @@ using namespace studio;
 
 /* === M A C R O S ========================================================= */
 
-#define use_colorspace_gamma()	App::use_colorspace_gamma
-#define colorspace_gamma()	(2.2f)
-#define gamma_in(x)		((x>=0)?pow((float)x,1.0f/colorspace_gamma()):-pow((float)-x,1.0f/colorspace_gamma()))
-#define gamma_out(x)	((x>=0)?pow((float)x,colorspace_gamma()):-pow((float)-x,colorspace_gamma()))
-
 /* === G L O B A L S ======================================================= */
 
 /* === P R O C E D U R E S ================================================= */
@@ -114,7 +110,7 @@ ColorSlider::adjust_color(Type type, Color &color, float amount)
 }
 
 bool
-ColorSlider::redraw(GdkEventExpose*bleh)
+ColorSlider::redraw(GdkEventExpose */*bleh*/)
 {
 	Color color(color_);
 
@@ -158,61 +154,32 @@ ColorSlider::redraw(GdkEventExpose*bleh)
 	Glib::RefPtr<Gdk::GC> gc(Gdk::GC::create(get_window()));
 	const Color bg1(0.75, 0.75, 0.75);
 	const Color bg2(0.5, 0.5, 0.5);
-	Gdk::Color gdk_c;
 	int i;
 	for(i=width-1;i>=0;i--)
 	{
-		color_func(color,float(i)/float(width));
+		color_func(color,
+				   (use_colorspace_gamma() && type<TYPE_U)
+				   ? gamma_out(float(i)/float(width))
+				   :		  (float(i)/float(width)));
 		const Color c1(Color::blend(color,bg1,1.0).clamped());
 		const Color c2(Color::blend(color,bg2,1.0).clamped());
 		assert(c1.is_valid());
 		assert(c2.is_valid());
 
-		gushort r1;
-		gushort g1;
-		gushort b1;
-		gushort r2;
-		gushort g2;
-		gushort b2;
-
-		if(use_colorspace_gamma() && (type<TYPE_U))
-		{
-			r1=(256*App::gamma.r_F32_to_U8(gamma_out(c1.get_r())));
-			g1=(256*App::gamma.g_F32_to_U8(gamma_out(c1.get_g())));
-			b1=(256*App::gamma.b_F32_to_U8(gamma_out(c1.get_b())));
-			r2=(256*App::gamma.r_F32_to_U8(gamma_out(c2.get_r())));
-			g2=(256*App::gamma.g_F32_to_U8(gamma_out(c2.get_g())));
-			b2=(256*App::gamma.b_F32_to_U8(gamma_out(c2.get_b())));
-		}
-		else
-		{
-			r1=(256*App::gamma.r_F32_to_U8(c1.get_r()));
-			g1=(256*App::gamma.g_F32_to_U8(c1.get_g()));
-			b1=(256*App::gamma.b_F32_to_U8(c1.get_b()));
-			r2=(256*App::gamma.r_F32_to_U8(c2.get_r()));
-			g2=(256*App::gamma.g_F32_to_U8(c2.get_g()));
-			b2=(256*App::gamma.b_F32_to_U8(c2.get_b()));
-		}
-
-
 		if((i*2/height)&1)
 		{
-			gdk_c.set_rgb(r1,g1,b1);
-			gc->set_rgb_fg_color(gdk_c);
+			gc->set_rgb_fg_color(colorconv_synfig2gdk(c1));
 			get_window()->draw_rectangle(gc, true, ca.get_x()+i, ca.get_y(), 1, height/2);
 
-			gdk_c.set_rgb(r2,g2,b2);
-			gc->set_rgb_fg_color(gdk_c);
+			gc->set_rgb_fg_color(colorconv_synfig2gdk(c2));
 			get_window()->draw_rectangle(gc, true, ca.get_x()+i, ca.get_y()+height/2, 1, height/2);
 		}
 		else
 		{
-			gdk_c.set_rgb(r2,g2,b2);
-			gc->set_rgb_fg_color(gdk_c);
+			gc->set_rgb_fg_color(colorconv_synfig2gdk(c2));
 			get_window()->draw_rectangle(gc, true, ca.get_x()+i, ca.get_y(), 1, height/2);
 
-			gdk_c.set_rgb(r1,g1,b1);
-			gc->set_rgb_fg_color(gdk_c);
+			gc->set_rgb_fg_color(colorconv_synfig2gdk(c1));
 			get_window()->draw_rectangle(gc, true, ca.get_x()+i, ca.get_y()+height/2, 1, height/2);
 		}
 	}
