@@ -2,7 +2,7 @@
 /*!	\file widget_curves.cpp
 **	\brief Template File
 **
-**	$Id: widget_curves.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: widget_curves.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -454,7 +454,7 @@ Widget_Curves::on_event(GdkEvent *event)
 }
 
 bool
-Widget_Curves::redraw(GdkEventExpose*bleh)
+Widget_Curves::redraw(GdkEventExpose */*bleh*/)
 {
 	const int h(get_height());
 	const int w(get_width());
