@@ -2,7 +2,7 @@
 /*!	\file widget_defaults.cpp
 **	\brief Template File
 **
-**	$Id: widget_defaults.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: widget_defaults.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -78,7 +78,7 @@ public:
 	}
 
 	bool
-	redraw(GdkEventExpose*bleh)
+	redraw(GdkEventExpose */*bleh*/)
 	{
 		Glib::RefPtr<Gdk::GC> gc(Gdk::GC::create(get_window()));
 
