@@ -2,10 +2,11 @@
 /*!	\file widget_gradient.cpp
 **	\brief Template File
 **
-**	$Id: widget_gradient.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: widget_gradient.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -119,7 +120,7 @@ Widget_Gradient::~Widget_Gradient()
 
 #define CONTROL_HEIGHT		16
 bool
-Widget_Gradient::redraw(GdkEventExpose*bleh)
+Widget_Gradient::redraw(GdkEventExpose */*bleh*/)
 {
 	const int h(get_height());
 	const int w(get_width());
@@ -203,6 +204,7 @@ void
 Widget_Gradient::remove_cpoint(float x)
 {
 	gradient_.erase(gradient_.proximity(x));
+	signal_value_changed_();
 	queue_draw();
 }
 
