@@ -2,7 +2,7 @@
 /*!	\file widget_sound.cpp
 **	\brief Widget Sound Implementation File
 **
-**	$Id: widget_sound.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: widget_sound.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -137,7 +137,7 @@ void studio::Widget_Sound::draw()
 	on_expose_event();
 }
 
-bool studio::Widget_Sound::on_expose_event(GdkEventExpose *heh)
+bool studio::Widget_Sound::on_expose_event(GdkEventExpose */*heh*/)
 {
 	if(!get_window()) return false;
 
