@@ -2,10 +2,11 @@
 /*!	\file widget_timeslider.cpp
 **	\brief Time Slider Widget Implementation File
 **
-**	$Id: widget_timeslider.cpp 465 2007-04-12 15:10:11Z dooglus $
+**	$Id: widget_timeslider.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2004 Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -311,7 +312,7 @@ studio::render_time_point_to_window(
 /* === M E T H O D S ======================================================= */
 
 /* === E N T R Y P O I N T ================================================= */
-double defaultfps = 0;
+double defaultfps = 24;
 const int fullheight = 20;
 
 Widget_Timeslider::Widget_Timeslider()
@@ -402,7 +403,7 @@ void Widget_Timeslider::refresh()
 	}
 }*/
 
-bool Widget_Timeslider::redraw(bool doublebuffer)
+bool Widget_Timeslider::redraw(bool /*doublebuffer*/)
 {
 	Glib::RefPtr<Gdk::Window> window = get_window();
 
