@@ -2,7 +2,7 @@
 /*!	\file widget_timeslider.h
 **	\brief Time Slider Widget Header
 **
-**	$Id: widget_timeslider.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: widget_timeslider.h 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2004 Adrian Bentley
@@ -84,7 +84,7 @@ protected: //implementation that other interfaces can see
 	virtual bool on_button_press_event(GdkEventButton *event); //for clicking
 	virtual bool on_button_release_event(GdkEventButton *event); //for clicking
 
-	virtual bool on_expose_event(GdkEventExpose *event) {redraw(); return true;}//for drawing
+	virtual bool on_expose_event(GdkEventExpose */*event*/) {redraw(); return true;}//for drawing
 
 	virtual bool redraw(bool doublebuffer = false);
 
