@@ -2,10 +2,11 @@
 /*!	\file workarea.h
 **	\brief Template Header
 **
-**	$Id: workarea.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: workarea.h 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -105,6 +106,7 @@ class WorkArea : public Gtk::Table, public Duckmatic
 	friend class WorkAreaTarget_Full;
 	friend class DirtyTrap;
 	friend class WorkAreaRenderer;
+	friend class WorkAreaProgress;
 
 	/*
  -- ** -- P U B L I C   T Y P E S ---------------------------------------------
@@ -235,6 +237,13 @@ private:
 
 	etl::loose_handle<synfig::ValueNode> selected_value_node_;
 
+	bool allow_duck_clicks;
+	bool allow_layer_clicks;
+	bool cancel;
+	bool curr_guide_is_x;
+	bool dirty;
+	bool queued;
+	bool rendering;
 
 	/*
  -- ** -- P U B L I C   D A T A -----------------------------------------------
@@ -256,16 +265,20 @@ public:
 	int get_tile_w()const { return tile_w; }
 	int get_tile_h()const { return tile_h; }
 
-	bool solid_lines;
-	bool rendering;
-	bool dirty;
-	bool queued;
-	bool cancel;
-	bool allow_layer_clicks;
-	bool allow_duck_clicks;
+	bool get_allow_layer_clicks() { return allow_layer_clicks; }
+	void set_allow_layer_clicks(bool value) { allow_layer_clicks=value; }
 
+	bool get_allow_duck_clicks() { return allow_duck_clicks; }
+	void set_allow_duck_clicks(bool value) { allow_duck_clicks=value; }
+
+	// used in renderer_ducks.cpp
+	bool solid_lines;
+
+	// used in renderer_guides.cpp
 	GuideList::iterator curr_guide;
-	bool curr_guide_is_x;
+
+	// used in renderer_timecode.cpp
+	int timecode_width, timecode_height;
 
 	/*
  -- ** -- P R I V A T E   M E T H O D S ---------------------------------------
