@@ -2,7 +2,7 @@
 /*!	\file workarearenderer.cpp
 **	\brief Template File
 **
-**	$Id: workarearenderer.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: workarearenderer.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -91,15 +91,15 @@ WorkAreaRenderer::set_work_area(WorkArea* x)
 
 void
 WorkAreaRenderer::render_vfunc(
-	const Glib::RefPtr<Gdk::Drawable>& window,
-	const Gdk::Rectangle& expose_area
+	const Glib::RefPtr<Gdk::Drawable>& /*window*/,
+	const Gdk::Rectangle& /*expose_area*/
 )
 {
 }
 
 bool
 WorkAreaRenderer::event_vfunc(
-	GdkEvent* event
+	GdkEvent* /*event*/
 )
 {
 	return false;
