@@ -2,7 +2,7 @@
 /*!	\file valuenodedynamiclistremove.cpp
 **	\brief Template File
 **
-**	$Id: valuenodedynamiclistremove.cpp,v 1.1.1.1 2005/01/07 03:34:37 darco Exp $
+**	$Id: valuenodedynamiclistremove.cpp 336 2007-03-16 00:39:42Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -49,7 +49,7 @@ ACTION_SET_TASK(Action::ValueNodeDynamicListRemove,"remove");
 ACTION_SET_CATEGORY(Action::ValueNodeDynamicListRemove,Action::CATEGORY_VALUEDESC|Action::CATEGORY_VALUENODE|Action::CATEGORY_HIDDEN);
 ACTION_SET_PRIORITY(Action::ValueNodeDynamicListRemove,-19);
 ACTION_SET_VERSION(Action::ValueNodeDynamicListRemove,"0.0");
-ACTION_SET_CVS_ID(Action::ValueNodeDynamicListRemove,"$Id: valuenodedynamiclistremove.cpp,v 1.1.1.1 2005/01/07 03:34:37 darco Exp $");
+ACTION_SET_CVS_ID(Action::ValueNodeDynamicListRemove,"$Id: valuenodedynamiclistremove.cpp 336 2007-03-16 00:39:42Z dooglus $");
 
 /* === G L O B A L S ======================================================= */
 
@@ -67,7 +67,7 @@ Action::ParamVocab
 Action::ValueNodeDynamicListRemove::get_param_vocab()
 {
 	ParamVocab ret(Action::CanvasSpecific::get_param_vocab());
-	
+
 	ret.push_back(ParamDesc("value_desc",Param::TYPE_VALUEDESC)
 		.set_local_name(_("ValueDesc"))
 	);
@@ -76,9 +76,9 @@ Action::ValueNodeDynamicListRemove::get_param_vocab()
 }
 
 bool
-Action::ValueNodeDynamicListRemove::is_canidate(const ParamList &x)
+Action::ValueNodeDynamicListRemove::is_candidate(const ParamList &x)
 {
-	if(canidate_check(get_param_vocab(),x))
+	if(candidate_check(get_param_vocab(),x))
 	{
 		ValueDesc value_desc(x.find("value_desc")->second.get_value_desc());
 		if(!value_desc.parent_is_value_node() || !ValueNode_DynamicList::Handle::cast_dynamic(value_desc.get_parent_value_node()))
@@ -95,20 +95,20 @@ Action::ValueNodeDynamicListRemove::set_param(const synfig::String& name, const
 	if(name=="value_desc" && param.get_type()==Param::TYPE_VALUEDESC)
 	{
 		ValueDesc value_desc(param.get_value_desc());
-		
+
 		if(!value_desc.parent_is_value_node())
 			return false;
-		
+
 		value_node=ValueNode_DynamicList::Handle::cast_dynamic(value_desc.get_parent_value_node());
-		
+
 		if(!value_node)
 			return false;
-		
+
 		index=value_desc.get_index();
-		
+
 		return true;
 	}
-	
+
 	return Action::CanvasSpecific::set_param(name,param);
 }
 
@@ -122,13 +122,13 @@ Action::ValueNodeDynamicListRemove::is_ready()const
 
 void
 Action::ValueNodeDynamicListRemove::perform()
-{	
+{
 	if(index>=value_node->link_count())
 		index=value_node->link_count()-1;
 
 	list_entry=value_node->list[index];
 	value_node->erase((value_node->list.begin()+index)->value_node);
-		
+
 	// Signal that a layer has been inserted
 	value_node->changed();
 /*_if(get_canvas_interface())
@@ -142,7 +142,7 @@ void
 Action::ValueNodeDynamicListRemove::undo()
 {
 	value_node->add(list_entry,index);
-	
+
 	// Signal that a layer has been inserted
 	value_node->changed();
 /*_if(get_canvas_interface())
