@@ -2,10 +2,11 @@
 /*!	\file waypointsetsmart.cpp
 **	\brief Template File
 **
-**	$Id: waypointsetsmart.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: waypointsetsmart.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -53,12 +54,12 @@ using namespace Action;
 
 ACTION_INIT(Action::WaypointSetSmart);
 ACTION_SET_NAME(Action::WaypointSetSmart,"waypoint_set_smart");
-ACTION_SET_LOCAL_NAME(Action::WaypointSetSmart,"Connect");
+ACTION_SET_LOCAL_NAME(Action::WaypointSetSmart,"Add Waypoint");
 ACTION_SET_TASK(Action::WaypointSetSmart,"set");
 ACTION_SET_CATEGORY(Action::WaypointSetSmart,Action::CATEGORY_WAYPOINT|Action::CATEGORY_VALUEDESC|Action::CATEGORY_VALUENODE);
 ACTION_SET_PRIORITY(Action::WaypointSetSmart,0);
 ACTION_SET_VERSION(Action::WaypointSetSmart,"0.0");
-ACTION_SET_CVS_ID(Action::WaypointSetSmart,"$Id: waypointsetsmart.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::WaypointSetSmart,"$Id: waypointsetsmart.cpp 848 2007-10-06 02:25:36Z dooglus $");
 
 
 /*#ifdef DEBUGPOINT
