@@ -2,7 +2,7 @@
 /*!	\file blineconvert.cpp
 **	\brief Template File
 **
-**	$Id: blineconvert.cpp 465 2007-04-12 15:10:11Z dooglus $
+**	$Id: blineconvert.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -246,7 +246,7 @@ void GetFirstDerivatives(const std::vector<synfig::Point> &f, unsigned int left,
 
 void GetSimpleDerivatives(const std::vector<synfig::Point> &f, int left, int right,
 							std::vector<synfig::Point> &df, int outleft,
-							const std::vector<synfig::Real> &di)
+							const std::vector<synfig::Real> &/*di*/)
 {
 	int i1,i2,i;
 	int offset = 2; //df = 1/2 (f[i+o]-f[i-o])
