@@ -2,10 +2,11 @@
 /*!	\file canvasinterface.cpp
 **	\brief Template File
 **
-**	$Id: canvasinterface.cpp 452 2007-04-10 15:23:05Z dooglus $
+**	$Id: canvasinterface.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -103,7 +104,13 @@ CanvasInterface::set_time(synfig::Time x)
 	}
 	if(cur_time_.is_equal(x))
 		return;
-	cur_time_=x;
+	get_canvas()->set_time(cur_time_=x);
+
+	// update the time in all the child canvases
+	Canvas::Children children = get_canvas()->get_root()->children();
+	for (Canvas::Children::iterator iter = children.begin(); iter != children.end(); iter++)
+		if (handle<CanvasInterface> interface = get_instance()->find_canvas_interface(*iter))
+			interface->set_time(interface->get_canvas()->get_time());
 
 	signal_time_changed()();
 	signal_dirty_preview()();
@@ -463,7 +470,7 @@ CanvasInterface::jump_to_prev_keyframe()
 }
 
 bool
-CanvasInterface::import(const synfig::String &filename, bool copy)
+CanvasInterface::import(const synfig::String &filename, bool /*copy*/)
 {
 	Action::PassiveGrouper group(get_instance().get(),_("Import Image"));
 
@@ -489,7 +496,7 @@ CanvasInterface::import(const synfig::String &filename, bool copy)
 
 		Layer::Handle layer(add_layer_to("PasteCanvas",get_canvas()));
 		if(!layer)
-			throw String(_("Unable to create \"PasteCanvas\" layer"));
+			throw String(_("Unable to create \"Paste Canvas\" layer"));
 		if(!layer->set_param("canvas",ValueBase(outside_canvas)))
 			throw int();
 
@@ -508,8 +515,6 @@ CanvasInterface::import(const synfig::String &filename, bool copy)
 		return false;
 	}
 
-
-
 	if(!Importer::book().count(ext))
 	{
 		get_ui_interface()->error(_("I don't know how to open images of this type -- ")+ext);
@@ -617,7 +622,7 @@ CanvasInterface::waypoint_remove(synfigapp::ValueDesc value_desc,synfig::Waypoin
 
 
 void
-CanvasInterface::auto_export(ValueNode::Handle value_node)
+CanvasInterface::auto_export(ValueNode::Handle /*value_node*/)
 {
 /*
 	// Check to see if we are already exported.
@@ -643,7 +648,7 @@ CanvasInterface::auto_export(ValueNode::Handle value_node)
 }
 
 void
-CanvasInterface::auto_export(const ValueDesc& value_desc)
+CanvasInterface::auto_export(const ValueDesc& /*value_desc*/)
 {
 	// THIS FUNCTION IS DEPRECATED, AND IS NOW A STUB.
 #if 0
