@@ -2,10 +2,11 @@
 /*!	\file synfigapp/instance.cpp
 **	\brief Instance
 **
-**	$Id: instance.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: instance.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -60,7 +61,6 @@ bool
 synfigapp::is_editable(synfig::ValueNode::Handle value_node)
 {
 	if(ValueNode_Const::Handle::cast_dynamic(value_node)
-		|| ValueNode_TimedSwap::Handle::cast_dynamic(value_node)
 		|| ValueNode_Animated::Handle::cast_dynamic(value_node)
 		|| ValueNode_Composite::Handle::cast_dynamic(value_node)
 		|| ValueNode_RadialComposite::Handle::cast_dynamic(value_node)
@@ -148,18 +148,6 @@ Instance::save()const
 	return ret;
 }
 
-bool
-Instance::save_as(const std::string &file_name)const
-{
-	bool ret=save_canvas(file_name,canvas_);
-	if(ret)
-	{
-		reset_action_count();
-		const_cast<sigc::signal<void>& >(signal_saved_)();
-	}
-	return ret;
-}
-
 bool
 Instance::save_as(const std::string &file_name)
 {
@@ -177,9 +165,7 @@ Instance::save_as(const std::string &file_name)
 		signal_saved_();
 	}
 	else
-	{
 		set_file_name(old_file_name);
-	}
 
 	signal_filename_changed_();
 
