@@ -2,7 +2,7 @@
 /*!	\file synfigapp/main.cpp
 **	\brief Template File
 **
-**	$Id: main.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: main.cpp 821 2007-10-03 02:17:55Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -376,7 +376,7 @@ synfigapp::Main::select_input_device(InputDevice::Handle input_device)
 {
 	assert(input_device);
 
-	synfig::info("Input device changed to \"%s\"",input_device->get_id().c_str());
+	// synfig::info("Input device changed to \"%s\"",input_device->get_id().c_str());
 
 	selected_input_device_=input_device;
 
