@@ -2,10 +2,11 @@
 /*!	\file settings.cpp
 **	\brief Template File
 **
-**	$Id: settings.cpp 423 2007-04-04 19:31:26Z dooglus $
+**	$Id: settings.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -194,7 +195,8 @@ Settings::save_to_file(const synfig::String& filename)const
 			for(iter=key_list.begin();iter!=key_list.end();++iter)
 			{
 				if(!file)return false;
-				file<<*iter<<'='<<get_value(*iter)<<endl;
+				String ret = get_value(*iter);
+				if (ret != String()) file<<*iter<<'='<<ret<<endl;
 			}
 		}
 
