@@ -2,7 +2,7 @@
 /*!	\file uimanager.cpp
 **	\brief Template File
 **
-**	$Id: uimanager.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: uimanager.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -149,7 +149,7 @@ ConsoleUIInterface::warning(const std::string &task)
 }
 
 bool
-ConsoleUIInterface::amount_complete(int current, int total)
+ConsoleUIInterface::amount_complete(int /*current*/, int /*total*/)
 {
 	return true;
 }
